@@ -33,11 +33,13 @@ XEPlugin_Animator::XEPlugin_Animator(QObject *parent, const char *name)
  : QObject(parent, name)
 {
 	XEObject::xPluginAdd(this);
+	animatorCounter=0;
 }
 
 
 XEPlugin_Animator::~XEPlugin_Animator()
 {
+	//qWarning("XEPlugin_Animator::~XEPlugin_Animator()");
 }
 
 
@@ -65,22 +67,26 @@ void XEPlugin_Animator::xSetup()
 	}
 	ActiveConfiguration=Configurator->xGetConfiguration();
 
-	onClickAnimation="bounce";
+	onClickAnimation="bouncelong";
 	onRaiseAnimation="micro";
 	onCloseAnimation="poof";
+	onHideAnimation="slide";
+	onShowAnimation="slide";
 }
 
 
 /*!
     \fn XEPlugin_Animator::xEventMouseClick(int,int,int,int)
  */
-void XEPlugin_Animator::xEventMouseClick(int icon,int x,int y,int button)
+void XEPlugin_Animator::xEventMouseClick(int icon,int ,int ,int button)
 {
 	//if(AnimationsMutex.tryLock()==false)return;
 #ifndef ENABLE_FINAL
 	qWarning("Animation");
 #endif
-	if(icon<0||icon>=ActiveConfiguration->ObjectsIcons.count())return;
+	if(icon<0)return;
+	uint TargetIcon=(uint)icon;
+	if(TargetIcon>=ActiveConfiguration->ObjectsIcons.count())return;
 #ifndef ENABLE_FINAL
 	qWarning("xeplugin_animator.cpp:67");
 #endif
@@ -90,15 +96,33 @@ void XEPlugin_Animator::xEventMouseClick(int icon,int x,int y,int button)
 	
 	//0.25 patch
 	// this will not animate a separator
-	if(ActiveConfiguration->ObjectsIcons.at(icon)->Info.className=="GSeparator")return;
+	if(ActiveConfiguration->ObjectsIcons.at(TargetIcon)->Info.className=="GSeparator")return;
 	
-	if(ActiveConfiguration->ObjectsIcons.at(icon)->Tasks.TaskInfo==NULL)
+	// 0.32
+	// with plugin click we dont bounce
+	XGIcon *target=xGDocker->getObjectIcon(TargetIcon);
+	if(target!=NULL	&& target->xEnabledClickClass())
 	{
-		xAnimateBounce(this->xGDocker->getObjectIcon(icon));
+		return;
+	}
+	if(ActiveConfiguration->ObjectsIcons.at(TargetIcon)->Tasks.TaskInfo==NULL)
+	{
+		if(onClickAnimation=="bouncelong"
+		// We check if we may trace the window, not all has got the dcop or task interface configured so:
+&&
+ActiveConfiguration->ObjectsIcons.at(TargetIcon)->Tasks.WindowTitle.count()>0
+		)
+		{
+		this->xStartAnimate(this->xGDocker->getObjectIcon(TargetIcon));
+		}
+		else
+		{
+		xAnimateBounce(this->xGDocker->getObjectIcon(TargetIcon));
+		}
 	}
 	else
 	{
-		xAnimateMicro(this->xGDocker->getObjectIcon(icon));
+		xAnimateMicro(this->xGDocker->getObjectIcon(TargetIcon));
 	}
 }
 
@@ -108,7 +132,8 @@ void XEPlugin_Animator::xEventMouseClick(int icon,int x,int y,int button)
  */
 void XEPlugin_Animator::xStop()
 {
-    /// @todo implement me
+	//if(AnimationsMutex.tryLock()==false)return;
+	AnimationsMutex.tryLock();
 }
 
 
@@ -120,7 +145,11 @@ void XEPlugin_Animator::xStart()
 #ifndef ENABLE_FINAL
 	qWarning("void XEPlugin_Animator::xStart() [97]");
 #endif
-	for(int i=0;i<ActiveConfiguration->Plugins.Plugin.count(); i++)
+	// 0.27
+	connect(xGDocker,SIGNAL(xEventDockerShowed()),this,SLOT(xEventDockerShowed()));
+	connect(xGDocker,SIGNAL(xEventDockerHidden()),this,SLOT(xEventDockerHidden()));
+	
+	for(uint i=0;i<ActiveConfiguration->Plugins.Plugin.count(); i++)
 	{
 #ifndef ENABLE_FINAL
 		qWarning(ActiveConfiguration->Plugins.Plugin.at(i)->Info.Name);
@@ -140,11 +169,15 @@ ActiveConfiguration->Plugins.Plugin.at(i)->xmlConfiguration.item(0).toElement().
 #endif
 			
 			onClickAnimation=
-			ActiveConfiguration->Plugins.Plugin.at(i)->xmlConfiguration.item(0).toElement().attribute("onClickAnimation", "bounce");
+			ActiveConfiguration->Plugins.Plugin.at(i)->xmlConfiguration.item(0).toElement().attribute("onClickAnimation", "bouncelong");
 			onRaiseAnimation=
 			ActiveConfiguration->Plugins.Plugin.at(i)->xmlConfiguration.item(0).toElement().attribute("onRaiseAnimation", "micro");
 			onCloseAnimation=
 			ActiveConfiguration->Plugins.Plugin.at(i)->xmlConfiguration.item(0).toElement().attribute("onCloseAnimation", "poof");
+			onHideAnimation=
+			ActiveConfiguration->Plugins.Plugin.at(i)->xmlConfiguration.item(0).toElement().attribute("onHideAnimation", "slide");
+			onShowAnimation=
+			ActiveConfiguration->Plugins.Plugin.at(i)->xmlConfiguration.item(0).toElement().attribute("onShowAnimation", "slide");
 		}
 		else
 		{
@@ -162,7 +195,7 @@ ActiveConfiguration->Plugins.Plugin.at(i)->xmlConfiguration.item(0).toElement().
 			QStringList	a;
 			// Creating the Attributes via the standard plugin interface
 			xGetParameterList(&a);
-			for(int istoringXML=0;istoringXML<a.count();istoringXML++)
+			for(uint istoringXML=0;istoringXML<a.count();istoringXML++)
 			{
 				QString returnValue;
 				xGetParameter(a[istoringXML],returnValue);
@@ -182,6 +215,10 @@ ActiveConfiguration->Plugins.Plugin.at(i)->xmlConfiguration.item(0).toElement().
 	if(onClickAnimation=="bounce")
 	connect(xGDocker,SIGNAL(xEventMouseClick(int,int,int,int)),
 		this,SLOT(xEventMouseClick(int,int,int,int)));
+	if(onClickAnimation=="bouncelong")
+	connect(xGDocker,SIGNAL(xEventMouseClick(int,int,int,int)),
+		this,SLOT(xEventMouseClick(int,int,int,int)));
+
 	connect(xGDocker,SIGNAL(xEventReset(int,int)),
 		this,SLOT(xEventReset(int,int)));
 	connect(xGDocker,SIGNAL(xEventAnimateTo(int,int,int,int)),
@@ -273,8 +310,10 @@ void XEPlugin_Animator::xEventReset(int x, int y)
  */
 void XEPlugin_Animator::xAnimate()
 {
-	timespec req,   rem;
-	req.tv_nsec=ActiveConfiguration->Engine.SleepAnimations;
+	// 0.27 code clean
+	//timespec req,   rem;
+	//req.tv_nsec=ActiveConfiguration->Engine.SleepAnimations;
+	
 	if(xGDocker->getRaised()&&xGDocker->xLastX==mouse.x()&&xGDocker->xLastY==mouse.y())
 	{
 		mouse.setY(mouse.y()-moltiplier);
@@ -322,8 +361,8 @@ void XEPlugin_Animator::xEventAnimateTo(int x,int y,int fx,int fy)
  */
 void XEPlugin_Animator::xAnimateTo()
 {
-	timespec req,   rem;
-	req.tv_nsec=ActiveConfiguration->Engine.SleepAnimations;
+//	timespec req,   rem;
+//	req.tv_nsec=ActiveConfiguration->Engine.SleepAnimations;
 	//qWarning("undoreset polling");
 	if(
 	xGDocker->xLastX<mousef.x()+20&&xGDocker->xLastX>mousef.x()-20 &&
@@ -397,16 +436,16 @@ void XEPlugin_Animator::xAnimateMicro(XGIcon *Icon)
 void XEPlugin_Animator::xEventRemoveIcon(int icon)
 {
 	if(AnimationsMutex.tryLock()==false)return;
-	timespec req,   rem;
-	req.tv_nsec=ActiveConfiguration->Engine.SleepAnimations*1000*1000;
-	req.tv_sec=0;
+//	timespec req,   rem;
+//	req.tv_nsec=ActiveConfiguration->Engine.SleepAnimations*1000*1000;
+//	req.tv_sec=0;
 	// poof animation
 #ifndef ENABLE_FINAL
 	qWarning("Poof Animations");
 #endif
 	XGIcon *Icon=xGDocker->getObjectIcon(icon);
-	int lastx=Icon->xPosition.x();
-	int lasty=Icon->xPosition.y();
+	//int lastx=Icon->xPosition.x();
+	//int lasty=Icon->xPosition.y();
 	int lastz=Icon->xZoom;
 	QImage Poof=Icon->Poof;
 	if(Poof.isNull())
@@ -414,16 +453,15 @@ void XEPlugin_Animator::xEventRemoveIcon(int icon)
 		Poof=ActiveConfiguration->Theme.Poof;
 	}
 #ifndef ENABLE_FINAL
-#else
 	char pippo[50];
 	sprintf(pippo,"Poof: %d %d %d",
 		lastz,
 		Poof.width(),
 		Poof.height());
+#else
 #endif
 	Poof=Poof.smoothScale(lastz,lastz,QImage::ScaleMax);
 #ifndef ENABLE_FINAL
-#else
 	qWarning(pippo);
 	sprintf(pippo,"Poof Size: %d %d",
 		lastz,
@@ -450,7 +488,6 @@ void XEPlugin_Animator::xEventRemoveIcon(int icon)
 		//req*10);
 		usleep(ActiveConfiguration->Engine.SleepAnimations*100);
 		//nanosleep(&req,&rem);
-		qWarning("Poof Animations !!!");
 #ifndef ENABLE_FINAL
 		qWarning("Poof Animations !!!");
 #endif
@@ -474,13 +511,16 @@ void XEPlugin_Animator::xAnimateStepBounce()
 {
 	//qWarning("Animate::Bounce Step!");
 	if(lastIcon==NULL)return;
+	if(xGDocker->xGetIconIndex(lastIcon)<0)return;
 	
-	double radr=6.28/360;
+	const double radr=6.28/360;
+	const double rfine=radr*360;
+	double acc;
 	static double radians=0;
 	int lasty=mousef.y();
 
 	
-	if(radians<=6.28
+	if(radians<rfine
 	&&
 	xGDocker->xLastX==mouse.x()
 	&&
@@ -490,11 +530,11 @@ void XEPlugin_Animator::xAnimateStepBounce()
 	&&
 	xGDocker->xLastY==mouse.y())
 	{
-		
 		radians=radians+radr*8;
+		acc=1.1/(0.1+sin(radians)*sin(radians));
 		lastIcon->xPosition.setY(
 		int(
-		lasty-sin(radians)*15*sin(radians)
+		lasty-sin(radians)*15*acc*sin(radians)
 		)
 		);
 		//xGDocker->xUpdate();
@@ -505,15 +545,21 @@ void XEPlugin_Animator::xAnimateStepBounce()
 		QTimer::singleShot(
 			ActiveConfiguration->Engine.SleepAnimations/10
 				,this,SLOT(xAnimateStepBounce()));
+
 	}
 	else
 	{
+		if(radians>=rfine)lastIcon->xPosition.setY(lasty);
+		
 		radians=0;
 #ifndef ENABLE_FINAL
 		qWarning("Interrotta animazione! 2");
 #endif
 #ifdef ENABLE_SPECIALENGINE2
 #else
+#ifdef ENABLE_FINAL		
+		qWarning("2");
+#endif
 		if(xGDocker->isAnimating)// ||!xGDocker->getRaised())
 #endif
 		{
@@ -521,8 +567,12 @@ void XEPlugin_Animator::xAnimateStepBounce()
 			qWarning("Interrotta animazione! 1");
 #endif
 			AnimationsMutex.unlock();
+
 			return;
 		}
+#ifdef ENABLE_FINAL		
+		qWarning("lastIcon->xPosition.setY(lasty);");
+#endif
 		lastIcon->xPosition.setY(lasty);
 		//xGDocker->isAnimating=0;
 		//xGDocker->xUpdate();
@@ -552,6 +602,7 @@ void XEPlugin_Animator::xAnimateStepMicro()
 	qWarning("Animate::Bounce Step!");
  #endif
 	if(lastIcon==NULL)return;
+	if(xGDocker->xGetIconIndex(lastIcon)<0)return;
 	
 	static int i=0;
 	int lasty=mousef.y();
@@ -638,14 +689,23 @@ void XEPlugin_Animator::xGetParameter(const QString sName, QString& sValue)
 	{
 		sValue=(onCloseAnimation);
 	}
-	if(sName=="onRaiseAnimation")
+	if(sName=="onShowAnimation")
 	{
-		sValue=(onRaiseAnimation);
+		sValue=(onShowAnimation);
 	}
 	if(sName=="onClickAnimation")
 	{
 		sValue=(onClickAnimation);
 	}
+	if(sName=="onRaiseAnimation")
+	{
+		sValue=(onRaiseAnimation);
+	}
+	if(sName=="onHideAnimation")
+	{
+		sValue=(onHideAnimation);
+	}
+
 }
 
 
@@ -657,6 +717,9 @@ void XEPlugin_Animator::xGetParameterList(QStringList *a)
 	a->append("onClickAnimation");
 	a->append("onRaiseAnimation");
 	a->append("onCloseAnimation");
+	a->append("onHideAnimation");
+	a->append("onShowAnimation");
+
 }
 
 
@@ -665,6 +728,15 @@ void XEPlugin_Animator::xGetParameterList(QStringList *a)
  */
 void XEPlugin_Animator::xSetupParameter(const QString sName,const QString sValue)
 {
+
+	if(sName=="onHideAnimation")
+	{
+		onHideAnimation=sValue;
+	}
+	if(sName=="onShowAnimation")
+	{
+		onShowAnimation=sValue;
+	}
 	if(sName=="onCloseAnimation")
 	{
 		onCloseAnimation=sValue;
@@ -678,7 +750,7 @@ void XEPlugin_Animator::xSetupParameter(const QString sName,const QString sValue
 		onClickAnimation=sValue;
 	}
 	
-	for(int i=0;i<ActiveConfiguration->Plugins.Plugin.count(); i++)
+	for(uint i=0;i<ActiveConfiguration->Plugins.Plugin.count(); i++)
 	{
 		if(ActiveConfiguration->Plugins.Plugin.at(i)->Info.Name=="xAnimator")
 		{
@@ -689,7 +761,215 @@ void XEPlugin_Animator::xSetupParameter(const QString sName,const QString sValue
 		("onRaiseAnimation",onRaiseAnimation);
 		ActiveConfiguration->Plugins.Plugin.at(i)->xmlConfiguration.item(0).toElement().setAttribute
 		("onCloseAnimation",onCloseAnimation);
+
+		ActiveConfiguration->Plugins.Plugin.at(i)->xmlConfiguration.item(0).toElement().setAttribute
+		("onShowAnimation",onShowAnimation);
+
+		ActiveConfiguration->Plugins.Plugin.at(i)->xmlConfiguration.item(0).toElement().setAttribute
+		("onHideAnimation",onHideAnimation);
 		}
+
 	}
 	
 }
+
+
+/*!
+    \fn XEPlugin_Animator::xEventDockerShowed()
+ */
+void XEPlugin_Animator::xEventDockerShowed()
+{
+
+#ifndef ENABLE_FINAL
+	qWarning("void XEPlugin_Animator::xEventDockerShowed()");
+#endif
+	
+	//if(xGDocker->isShown())return;
+	if(xGDocker->getRaised() )return;
+	if(onShowAnimation!="slide")return;
+
+//	timespec req,   rem;
+//	req.tv_nsec=ActiveConfiguration->Engine.SleepAnimations*1000*1000;
+//	req.tv_sec=0;
+	// poof animation
+#ifndef ENABLE_FINAL
+	qWarning("void XEPlugin_Animator::xEventDockerShowed() Animations");
+#endif
+	XGIcon *Icon=xGDocker->getObjectIcon(0);
+	
+	uint iconCicle=0;
+	int lasty=Icon->xPosition.y();
+	int lastybar=Icon->xPosDefault.y();
+	// TODO: yBar and xBar static
+	//int lastxbar;
+	//xGDocker->xBackgroundGetCoords(lastxbar,lastybar);
+	
+	int showSteps=10;
+	
+	int moltipler=ActiveConfiguration->Window.Height/showSteps;
+	for(iconCicle=0;iconCicle<ActiveConfiguration->ObjectsIcons.count();iconCicle++)
+		{
+			
+			Icon=xGDocker->getObjectIcon(iconCicle);
+			if(Icon->xExclude)continue;
+			Icon->xPosition.setY(ActiveConfiguration->Window.Height);
+			
+		}
+	
+	for(int i=moltipler/3;i>=0;i--)
+	{
+	
+		for(iconCicle=0;iconCicle<ActiveConfiguration->ObjectsIcons.count();iconCicle++)
+		{
+			Icon=xGDocker->getObjectIcon(iconCicle);
+			if(Icon->xExclude)continue;
+			Icon->xPosition.setY(lasty+i*moltipler);
+			
+		}
+		xGDocker->getObjectIcon(0)->xPosDefault.setY(lastybar+i*moltipler);
+		//xGDocker->xBackgroundMove(lastxbar,);
+
+		xGDocker->xDockerRedraw();
+		usleep(ActiveConfiguration->Engine.SleepAnimations*100);
+		//nanosleep(&req,&rem);
+#ifndef ENABLE_FINAL
+		qWarning(QString("i:%1 Y:%1 height:%1").arg(i).arg(Icon->xPosition.y()).arg(ActiveConfiguration->Window.Height));
+		qWarning("void XEPlugin_Animator::xEventDockerShowed() Animations !!!");
+#endif
+
+	}
+#ifndef ENABLE_FINAL
+	qWarning("void XEPlugin_Animator::xEventDockerShowed() Animations End");
+#endif
+}
+
+
+/*!
+    \fn XEPlugin_Animator::xEventDockerHidden()
+ */
+void XEPlugin_Animator::xEventDockerHidden()
+{
+#ifndef ENABLE_FINAL
+	qWarning("XEPlugin_Animator::xEventDockerHidden()");
+#endif
+	
+	//if(xGDocker->isShown())return;
+	if(xGDocker->getRaised())return;
+	if(onHideAnimation!="slide")return;
+	
+
+	//timespec req,   rem;
+	//req.tv_nsec=ActiveConfiguration->Engine.SleepAnimations*1000*1000;
+	//req.tv_sec=0;
+	// poof animation
+#ifndef ENABLE_FINAL
+	qWarning("XEPlugin_Animator::xEventDockerHidden() Animations");
+#endif
+	XGIcon *Icon=xGDocker->getObjectIcon(0);
+	
+	uint iconCicle=0;
+	int lasty=Icon->xPosition.y();
+	int lastybar=Icon->xPosDefault.y();
+	// TODO: yBar and xBar static
+	//int lastxbar;
+	//xGDocker->xBackgroundGetCoords(lastxbar,lastybar);
+	
+	int showSteps=10;
+	
+	int moltipler=ActiveConfiguration->Window.Height/showSteps;
+	for(iconCicle=0;iconCicle<ActiveConfiguration->ObjectsIcons.count();iconCicle++)
+		{
+			Icon=xGDocker->getObjectIcon(iconCicle);
+			if(Icon->xExclude)continue;
+			Icon->xPosition.setY(ActiveConfiguration->Window.Height);
+			
+		}
+	
+	int i;
+	for(i=0;i<moltipler/3;i++)
+	{
+	
+		for(iconCicle=0;iconCicle<ActiveConfiguration->ObjectsIcons.count();iconCicle++)
+		{
+			Icon=xGDocker->getObjectIcon(iconCicle);
+			if(Icon->xExclude)continue;
+			Icon->xPosition.setY(lasty+i*moltipler);
+			
+		}
+		xGDocker->getObjectIcon(0)->xPosDefault.setY(lastybar+i*moltipler);
+		//xGDocker->xBackgroundMove(lastxbar,);
+
+		xGDocker->xDockerRedraw();
+		
+		usleep(ActiveConfiguration->Engine.SleepAnimations*100);
+		//nanosleep(&req,&rem);
+#ifndef ENABLE_FINAL
+		qWarning(QString("i:%1 Y:%1 height:%1").arg(i).arg(Icon->xPosition.y()).arg(ActiveConfiguration->Window.Height));
+		qWarning("XEPlugin_Animator::xEventDockerHidden() Animations !!!");
+#endif
+
+	}
+	// restore all right coords
+	i=0;
+	for(iconCicle=0;iconCicle<ActiveConfiguration->ObjectsIcons.count();iconCicle++)
+	{
+		Icon=xGDocker->getObjectIcon(iconCicle);
+		if(Icon->xExclude)continue;
+		Icon->xPosition.setY(lasty+i*moltipler);
+		
+	}
+	xGDocker->getObjectIcon(0)->xPosDefault.setY(lastybar+i*moltipler);
+	
+	
+#ifndef ENABLE_FINAL
+	qWarning("XEPlugin_Animator::xEventDockerHidden() Animations End");
+#endif
+}
+
+
+/*!
+    \fn XEPlugin_Animator::xGetInfo(QStringList &)
+ */
+void XEPlugin_Animator::xGetInfo(QStringList &)
+{
+    /// @todo implement me
+}
+
+
+/*!
+    \fn XEPlugin_Animator::xStopAnimate()
+ */
+void XEPlugin_Animator::xStopAnimate()
+{
+	animatingIcon=NULL;
+}
+
+
+/*!
+    \fn XEPlugin_Animator::xStartAnimate(XGIcon *)
+ */
+void XEPlugin_Animator::xStartAnimate(XGIcon *TargetIcon)
+{
+	animatingIcon=TargetIcon;
+	xAnimateBounce((TargetIcon));
+	xStartAnimate();
+}
+void XEPlugin_Animator::xStartAnimate()
+{
+	int exint=0;
+	if(animatingIcon && ((exint=xGDocker->xGetIconIndex(animatingIcon))>=0)&& ActiveConfiguration->ObjectsIcons.at(exint)->Tasks.TaskInfo==NULL &&
+	ActiveConfiguration->ObjectsIcons.at(exint)->Tasks.dcopReady==0
+	&&
+	ActiveConfiguration->ObjectsIcons.at(exint)->Tasks.forceRunning==0
+	&&
+	animatorCounter<30)
+	{
+		xAnimateBounce((animatingIcon));
+		QTimer::singleShot(2000,this,SLOT(xStartAnimate()));
+	}
+	else
+	{
+		animatorCounter=0;
+		return;
+	}
+}
