@@ -60,8 +60,10 @@
 #include <kpopupmenu.h>
 #include <kcombobox.h> 
 
+#include <xematrix.h>
 
-XEPlugin_Configurator::XEPlugin_Configurator(QWidget *parent, const char *name)
+
+XEPlugin_Configurator::XEPlugin_Configurator(QWidget *, const char *name)
  : KMainWindow(0, name)
 {
 	XEObject::xPluginAdd(this);
@@ -120,8 +122,7 @@ void XEPlugin_Configurator::xSetup()
 	#endif
 	
 	XEConfiguration *Configurator=(XEConfiguration *)XEObject::xGetConfiguration();
-	xGDocker=(XGDocker *)XEObject::xGetDocker();
-	if(Configurator==NULL || xGDocker==NULL)
+	xGDocker=(XGDocker *)XEObject::xGetDocker();if(Configurator==NULL || xGDocker==NULL)
 	{
 		// Emits Signal of warning
 		//xWarningMsg(this,"error while searching for plugin");
@@ -173,6 +174,7 @@ void XEPlugin_Configurator::guiCreate()
     tabs->insertTab(vpage8,i18n("Plugins"));
     tabs->insertTab(vpage6,i18n("Draw Engine"));
     
+    AutoSave=new QCheckBox(i18n("Auto save on exit"),vpage1);
     create_about(vpage1);
     
     
@@ -212,6 +214,8 @@ void XEPlugin_Configurator::guiCreate()
     imgBackgroundOver=new QLineEdit(gpage3_g0);
     new QLabel(i18n("Separator"), gpage3_g0);
     imgBackgroundSeparator=new QLineEdit(gpage3_g0);
+    new QLabel(i18n("Desaturate background"), gpage3_g0);
+    imgBackground_Desaturate=new KIntSpinBox(gpage3_g0);
     imgBackground_Tiled=new QCheckBox(i18n("Tile the background image"),gb3_0);
     
     QVGroupBox *gb3_1=new QVGroupBox(i18n("Icons themes (search paths)"),vpage3);
@@ -222,18 +226,7 @@ void XEPlugin_Configurator::guiCreate()
     //QPushButton	*pIconsPathRemove=new QPushButton("Remove",gpage3_h);
     iconsPaths= new QListBox(gb3_1);
     
-    
-    /*
-			borderLeft="200"
-			borderTop="110"
-			Width="1024"
-			Height="150"
-			Top="100"
-			Left="0"
-			HeightDesktop="48"
-			TopForce="0"
-			LeftForce="0"
-    */
+
     
     QVButtonGroup *gb4_0=new QVButtonGroup(i18n("Docker position"),vpage4);
     QGrid	*gpage4_g0= new QGrid(3,gb4_0);
@@ -277,6 +270,7 @@ void XEPlugin_Configurator::guiCreate()
     
     SendToBackground=new QCheckBox(i18n("Auto Send to background"),gpage4_h2);
     RaiseOnEvents=new QCheckBox(i18n("Auto Raise on Events"),gpage4_h2);
+    FastHide=new QCheckBox(i18n("Enable Fast Hiding"),gpage4_h2);
     
     HideMouseCornerRight=new QCheckBox(i18n("Mouse must touch Right corner"),gpage4_h2);
     HideMouseCornerLeft=new QCheckBox(i18n("Mouse must touch Left corner"),gpage4_h2);
@@ -284,11 +278,11 @@ void XEPlugin_Configurator::guiCreate()
     gpage4_h2=new QGrid(3,gb4_2);
         
     new QLabel(i18n("Auto hide timeout (s)"), gpage4_h2);
-    QSlider *sHideTimeout=new QSlider(Qt::Horizontal,gpage4_h2);
+    sHideTimeout=new QSlider(Qt::Horizontal,gpage4_h2);
     HideTimeout=new KIntSpinBox(gpage4_h2);
     
     new QLabel(i18n("Auto Raise to Forground timeout (ms)"), gpage4_h2);
-    QSlider *sSendToForgroundTimeout=new QSlider(Qt::Horizontal,gpage4_h2);
+    sSendToForgroundTimeout=new QSlider(Qt::Horizontal,gpage4_h2);
     SendToForgroundTimeout=new KIntSpinBox(gpage4_h2);
     
     
@@ -330,6 +324,9 @@ void XEPlugin_Configurator::guiCreate()
     new QLabel(i18n("unMagnify sliding"), gpage4_h3);
     sHoriz=new QSlider(Qt::Horizontal,gpage4_h3);
     Horiz=new KIntSpinBox(gpage4_h3);
+
+    AutoResize=new QCheckBox(i18n("Auto resize icons if the dock does not fit into the screen"),gb4_3);
+
     
     QVButtonGroup *gb4_4=new QVButtonGroup(i18n("Visualizations Options"),vpage5);
     EnableThumbnail=new QCheckBox(i18n("Enable Thumbnails"),gb4_4);
@@ -369,8 +366,11 @@ void XEPlugin_Configurator::guiCreate()
 
     ToolBar->insertButton("apply",4);
     ToolBar->insertButton("fileopen",1);
-    ToolBar->insertButton("filesave",2);
-    ToolBar->insertButton("fileclose",3);
+    ToolBar->insertButton("filesave",100,true,"Save");
+    ToolBar->insertButton("filesaveas",2,true,"Save as");
+    ToolBar->insertButton("fileclose",3,true,"Close");
+    ToolBar->insertButton("wizard",101,true,"Wizard");
+    //ToolBar->insertWidget(AutoSave,5);
     
     
     // * Icons *
@@ -401,13 +401,37 @@ void XEPlugin_Configurator::guiCreate()
     QVBox	*objectsImages=new QVBox(objectsTabs);
     QVBox	*objectsActions=new QVBox(objectsTabs);
     QVBox	*objectsTasks=new QVBox(objectsTabs);
+    QVBox	*objectsDCOP=new QVBox(objectsTabs);
     QVBox	*objectsPlugin=new QVBox(objectsTabs);
     objectsTabs->insertTab(objectsInfo,		i18n("Info"));
     objectsTabs->insertTab(objectsImages,	i18n("Images"));
     objectsTabs->insertTab(objectsActions,	i18n("Actions"));
     objectsTabs->insertTab(objectsTasks,	i18n("Tasks"));
+    objectsTabs->insertTab(objectsDCOP,		i18n("DCOP"));
     objectsTabs->insertTab(objectsPlugin,	i18n("Plugin"));
     
+    
+	oPluginConfigure=new QPushButton("Configure",objectsPlugin);
+	connect(oPluginConfigure,SIGNAL(clicked()),this,SLOT(xRunCfg()));
+	QGrid *objectsPluginInfo=new QGrid(2,objectsPlugin);
+	new QLabel(i18n("Name"),objectsPluginInfo);
+	oPluginName=new QLabel("",objectsPluginInfo);
+	new QLabel(i18n("Version"),objectsPluginInfo);
+	oPluginVersion=new QLabel("",objectsPluginInfo);
+	new QLabel(i18n("Date"),objectsPluginInfo);
+	oPluginDate=new QLabel("",objectsPluginInfo);
+	new QLabel(i18n("Author"),objectsPluginInfo);
+	oPluginAuthor=new QLabel("",objectsPluginInfo);
+	new QLabel(i18n("mail"),objectsPluginInfo);
+	oPluginAuthorMail=new QLabel("",objectsPluginInfo);
+	new QLabel(i18n("Download"),objectsPluginInfo);
+	oPluginUrlDownload=new QLabel("",objectsPluginInfo);
+	new QLabel(i18n("Documentation"),objectsPluginInfo);
+	oPluginUrlDocumentation=new QLabel("",objectsPluginInfo);
+	new QLabel(i18n("Updates"),objectsPluginInfo);
+	oPluginUrlUpdate=new QLabel("",objectsPluginInfo);
+
+    
     oPluginCfg	=new KListView(objectsPlugin);
     oPluginCfg->addColumn(i18n("Name"));
     oPluginCfg->addColumn(i18n("Value"));
@@ -428,6 +452,27 @@ void XEPlugin_Configurator::guiCreate()
     objectsToolBarTasks->insertButton("window_new",15);
     objectsToolBarTasks->insertButton("remove",16);
     
+    
+    
+	//0.29
+	QGrid *objectsDCOPInfo=new QGrid(2,objectsDCOP);
+	new QLabel("new window function",objectsDCOPInfo);
+	odcopNewWindow=new QLineEdit(objectsDCOPInfo);
+	new QLabel("raise function",objectsDCOPInfo);
+	odcopRaise=new QLineEdit(objectsDCOPInfo);
+	new QLabel(i18n("close function"),objectsDCOPInfo);
+	odcopClose=new QLineEdit(objectsDCOPInfo);
+    objectsToolBarDCOP=new KToolBar(objectsDCOP);
+    iconsListDCOP= new KListView(objectsDCOP);
+    iconsListDCOP->addColumn(i18n("dcop name"));
+    iconsListDCOP->setItemsRenameable(true);
+    iconsListDCOP->setRenameable(0,true);
+    objectsToolBarDCOP->insertButton("apply",17);
+    objectsToolBarDCOP->insertButton("window_new",15);
+    objectsToolBarDCOP->insertButton("remove",16);
+
+    
+    
     QGrid	*gobjectsInfo=new QGrid(2,objectsInfo);
     new QLabel(i18n("Name"), gobjectsInfo);
     oName=new QLineEdit(gobjectsInfo);
@@ -446,23 +491,33 @@ void XEPlugin_Configurator::guiCreate()
     new QLabel(i18n("Icon"), gobjectsImages);
     oimgFileName=new QLineEdit(gobjectsImages);
     ioimgFileName=new KIconButton(gobjectsImages);
-    new QLabel(i18n("Arrow"), gobjectsImages);
+    new QLabel(i18n("Arrow Image (arrow.png)"), gobjectsImages);
     oimgFileArrow=new QLineEdit(gobjectsImages);
+    new QLabel(i18n(""), gobjectsImages);
+    new QLabel(i18n("Drop Image (drop.png)"), gobjectsImages);
+    oimgFileDrop=new QLineEdit(gobjectsImages);
+    new QLabel(i18n(""), gobjectsImages);
+
+    
     new QWidget(gobjectsImages);
     
     QVBox	*vobjectsActions=new QVBox(objectsActions);
     QGrid	*gobjectsActions=new QGrid(2,vobjectsActions);
     new QLabel(i18n("onClickExec"), gobjectsActions);
     oonClickExec=new QLineEdit(gobjectsActions);
+    new QLabel(i18n("onDropExec use %1 for filename"), gobjectsActions);
+    oonDropExec=new QLineEdit(gobjectsActions);
     
     pXMLActionList=new KListView(vobjectsActions);
+    pXMLActionList->addColumn(i18n("Info"));
     pXMLActionList->addColumn(i18n("Icon"));
     pXMLActionList->addColumn(i18n("Action"));
-    pXMLActionList->addColumn(i18n("data"));
+    pXMLActionList->addColumn(i18n("Data"));
     pXMLActionList->setItemsRenameable(true);
     pXMLActionList->setRenameable(0,true);
     pXMLActionList->setRenameable(1,true);
     pXMLActionList->setRenameable(2,true);
+    pXMLActionList->setRenameable(3,true);
     
     
     QGrid	*gobjectsTasks=new QGrid(2,objectsTasks);
@@ -522,13 +577,19 @@ void XEPlugin_Configurator::guiCreate()
     new QLabel(i18n("Icon"), gobjectsImages);
     aimgFileName=new QLineEdit(gobjectsImages);
     iaimgFileName=new KIconButton(gobjectsImages);
-    new QLabel(i18n("Arrow"), gobjectsImages);
+    new QLabel(i18n("Arrow Image (arrow.png)"), gobjectsImages);
     aimgFileArrow=new QLineEdit(gobjectsImages);
+    new QLabel(i18n(""), gobjectsImages);
+    new QLabel(i18n("Drop Image (drop.png)"), gobjectsImages);
+    aimgFileDrop=new QLineEdit(gobjectsImages);
     new QWidget(gobjectsImages);
+    new QLabel(i18n(""), gobjectsImages);
     
     gobjectsActions=new QGrid(2,objectsActions);
     new QLabel(i18n("onClickExec"), gobjectsActions);
     aonClickExec=new QLineEdit(gobjectsActions);
+    new QLabel(i18n("onDropExec use %1 for filename"), gobjectsActions);
+    aonDropExec=new QLineEdit(gobjectsActions);
     
     gobjectsTasks=new QGrid(2,objectsTasks);
     
@@ -593,10 +654,12 @@ void XEPlugin_Configurator::guiDefault()
 	imgBackgroundOver->setText("background-over.png");
 	imgBackgroundSeparator->setText("background-separator.png");
 	imgBackground_Tiled->setChecked(false);
-	
+	imgBackground_Desaturate->setValue(0);
+	imgBackground_Desaturate->setMinValue(0);
+	imgBackground_Desaturate->setMaxValue(100);
 	iconsPaths->clear();
 	
-	rAlignTop->setEnabled(true);
+	rAlignTop->setEnabled(false);
 	rAlignLeft->setEnabled(false);
 	rAlignRight->setEnabled(false);
 	rAlignBottom->setEnabled(true);
@@ -612,11 +675,25 @@ void XEPlugin_Configurator::guiDefault()
 	TopForce->setValue(0);
 	LeftForce->setValue(0);
 	HeightDesktop->setValue(48);
+	sSendToForgroundTimeout->setValue(0);
+	AutoSave->setChecked(true);
+	AutoResize->setChecked(true);
+
+	
 	
 	HideTimeout->setValue(60);
+	sHideTimeout->setValue(60);
+	
 	HideTimeout->setMaxValue(3600);
+	FastHide->setChecked(false);
+	
 	
 	SendToForgroundTimeout->setMaxValue(36000);
+	sSendToForgroundTimeout->setMaxValue(36000);
+	sSendToForgroundTimeout->setMinValue(0);
+	
+	sHideTimeout->setMaxValue(36000);
+	sHideTimeout->setMinValue(0);
 	
 	MaxIconsShowed->setMaxValue(MAX_ICONS);
 	
@@ -626,15 +703,23 @@ void XEPlugin_Configurator::guiDefault()
 	borderTop->setEnabled(false);
 	TopForce->setEnabled(true);
 	LeftForce->setEnabled(true);
-	HeightDesktop->setEnabled(false);
-	sHeightDesktop->setEnabled(false);
+	
+	
+	
+	HeightDesktop->setEnabled(true);
+	sHeightDesktop->setEnabled(true);
+	sSendToForgroundTimeout->setEnabled(true);
+	
+	sHideTimeout->setEnabled(true);
+
 	
 	
 	
 	Design->clear();
 	Design->insertItem("realosx");
 	Design->insertItem("osxbar");
-	Design->setCurrentText("realosx");
+	Design->insertItem("panther");
+	Design->setCurrentText("panther");
 	
 	
 	EnableThumbnail->setChecked(true);
@@ -646,7 +731,8 @@ void XEPlugin_Configurator::guiDefault()
 	SmoothTimeout->setValue(50);
 	SleepThreads->setValue(1000);
 	SleepAnimations->setValue(100);
-
+	InterpolationValue->setValue(2);
+	InterpolationValue->setMinValue(1);
 }
 
 
@@ -711,25 +797,31 @@ void XEPlugin_Configurator::guiPrepare()
 	connect(sLeftForce,SIGNAL(sliderMoved(int)),LeftForce,SLOT(setValue(int)));
 	connect(sTopForce,SIGNAL(sliderMoved(int)),TopForce,SLOT(setValue(int)));
 	
+	connect(sHeightDesktop,SIGNAL(sliderMoved(int)),HeightDesktop,SLOT(setValue(int)));
+	connect(sSendToForgroundTimeout,SIGNAL(sliderMoved(int)),SendToForgroundTimeout,SLOT(setValue(int)));
+	connect(sHideTimeout,SIGNAL(sliderMoved(int)),HideTimeout,SLOT(setValue(int)));
+
+	
+	
 	connect(LeftForce,SIGNAL(valueChanged(int)),sLeftForce,SLOT(setValue(int)));
 	connect(TopForce,SIGNAL(valueChanged(int)),sTopForce,SLOT(setValue(int)));
 	//ToolBar->setItemEnabled(4, false);
 	
 	
-	Size->setMaxValue(64);
+	Size->setMaxValue(256);
 	Size->setMinValue(16);
 	Size->setLineStep(16);
 	
-	SizeBig->setMaxValue(128);
+	SizeBig->setMaxValue(256);
 	SizeBig->setMinValue(16);
 	SizeBig->setLineStep(16);
 	
-	sSize->setMaxValue(64);
+	sSize->setMaxValue(256);
 	sSize->setMinValue(16);
 	sSize->setLineStep(16);
 	sSize->setPageStep(16);
 	
-	sSizeBig->setMaxValue(128);
+	sSizeBig->setMaxValue(256);
 	sSizeBig->setMinValue(16);
 	sSizeBig->setLineStep(16);
 	sSizeBig->setPageStep(16);
@@ -739,10 +831,10 @@ void XEPlugin_Configurator::guiPrepare()
 	sSize->setTickmarks(QSlider::Below);
 	sSizeBig->setTickmarks(QSlider::Below);
 	
-	sSizeBig->setMaxValue(128);
-	sSize->setMaxValue(128);
+	sSizeBig->setMaxValue(256);
+	sSize->setMaxValue(256);
 	Size->setValue(32);
-	SizeBig->setValue(128);
+	SizeBig->setValue(256);
 	
 	sSize->setValue(Size->value());
 	sSizeBig->setValue(SizeBig->value());
@@ -816,11 +908,27 @@ void XEPlugin_Configurator::guiPrepare()
 		SIGNAL(textChanged(const QString &)),
 		this,
 		SLOT(slot_oImgArrow_textChanged(const QString& )));
+	connect(oimgFileDrop,
+		SIGNAL(textChanged(const QString &)),
+		this,
+		SLOT(slot_oImgDrop_textChanged(const QString& )));
+	connect(aimgFileDrop,
+		SIGNAL(textChanged(const QString &)),
+		this,
+		SLOT(slot_aImgDrop_textChanged(const QString& )));
 		
 	connect(oonClickExec,
 		SIGNAL(textChanged(const QString &)),
 		this,
 		SLOT(slot_oOnClickExec_textChanged(const QString& )));
+	connect(oonDropExec,
+		SIGNAL(textChanged(const QString &)),
+		this,
+		SLOT(slot_oOnDropExec_textChanged(const QString& )));
+	connect(aonDropExec,
+		SIGNAL(textChanged(const QString &)),
+		this,
+		SLOT(slot_aOnDropExec_textChanged(const QString& )));
 		
 	// Alias
 	connect(iaimgFileName,
@@ -943,7 +1051,7 @@ void XEPlugin_Configurator::guiRefreshValues()
 		KDEIconLoader.loadIcon(
 				icon->Images.imgFileName,
 				KIcon::NoGroup,
-				ActiveConfiguration->Icons.Size
+				ActiveConfiguration->Icons.SizePrefer
 				);;
 		//xGDocker->xFindIconFile(icon->Images.imgFileName));
 		QListViewItem	*item=new QListViewItem(
@@ -985,7 +1093,7 @@ void XEPlugin_Configurator::guiRefreshValues()
 		KDEIconLoader.loadIcon(
 				icon->Images.imgFileName,
 				KIcon::NoGroup,
-				ActiveConfiguration->Icons.Size
+				ActiveConfiguration->Icons.SizePrefer
 				);;
 		//xGDocker->xFindIconFile(icon->Images.imgFileName));
 		QListViewItem	*item=new QListViewItem(
@@ -1022,7 +1130,7 @@ void XEPlugin_Configurator::guiRefreshValues()
 	if(ActiveConfiguration->Window.Align=="right")rAlignRight->setChecked(true);
 	
 
-	Size->setValue(ActiveConfiguration->Icons.Size);
+	Size->setValue(ActiveConfiguration->Icons.SizePrefer);
 	SizeBig->setValue(ActiveConfiguration->Icons.SizeBig);
 	// background
 	BackgroundPath->setText(ActiveConfiguration->Theme.BackgroundPath);
@@ -1033,6 +1141,7 @@ void XEPlugin_Configurator::guiRefreshValues()
 	imgBackgroundSeparator->setText(ActiveConfiguration->Theme.Background.imgBackgroundSeparator);
 	imgBackgroundLeft->setText(ActiveConfiguration->Theme.Background.imgBackgroundLeft);
 	imgBackgroundRight->setText(ActiveConfiguration->Theme.Background.imgBackgroundRight);
+	imgBackground_Desaturate->setValue(ActiveConfiguration->Theme.Background.Desaturate);
 	imgBackgroundCenter->setText(ActiveConfiguration->Theme.Background.imgBackgroundCenter);
 	imgBackgroundOver->setText(ActiveConfiguration->Theme.Background.imgBackgroundOver);
 	if(ActiveConfiguration->Theme.Background.Tiled)imgBackground_Tiled->setChecked(true);
@@ -1043,8 +1152,21 @@ void XEPlugin_Configurator::guiRefreshValues()
 	borderLeft->setValue(ActiveConfiguration->Window.borderLeft);
 	borderTop->setValue(ActiveConfiguration->Window.borderTop);
 	borderTop->setEnabled(false);
+	
 	HeightDesktop->setValue(ActiveConfiguration->Window.HeightDesktop);
-	HeightDesktop->setEnabled(false);
+	
+	HeightDesktop->setMaxValue(ActiveConfiguration->Icons.SizePrefer+16);
+	sHeightDesktop->setValue(ActiveConfiguration->Window.HeightDesktop);
+	
+	if(ActiveConfiguration->AutoSave)AutoSave->setChecked(true);
+	else AutoResize->setChecked(false);
+	if(ActiveConfiguration->AutoResize)AutoResize->setChecked(true);
+	else AutoResize->setChecked(false);
+
+
+	if(ActiveConfiguration->Window.FastHide)FastHide->setChecked(true);
+	else FastHide->setChecked(false);
+	//HeightDesktop->setEnabled(false);
 	TopForce->setValue(ActiveConfiguration->Window.TopForce);
 	LeftForce->setValue(ActiveConfiguration->Window.LeftForce);
 	
@@ -1059,7 +1181,12 @@ void XEPlugin_Configurator::guiRefreshValues()
 	else SendToBackground->setChecked(false);
 	if(ActiveConfiguration->Window.RaiseOnEvents)RaiseOnEvents->setChecked(true);
 	else RaiseOnEvents->setChecked(false);	
+	
 	SendToForgroundTimeout->setValue(ActiveConfiguration->Window.SendToForgroundTimeout);
+	sSendToForgroundTimeout->setValue(ActiveConfiguration->Window.SendToForgroundTimeout);
+	HideTimeout->setValue(ActiveConfiguration->Window.HideTimeout);
+	sHideTimeout->setValue(ActiveConfiguration->Window.HideTimeout);
+	
 	Separation->setValue(ActiveConfiguration->Icons.Separation);
 	Raise->setValue(ActiveConfiguration->Icons.Raise);
 	Horiz->setValue(ActiveConfiguration->Icons.Horiz);
@@ -1157,6 +1284,7 @@ void XEPlugin_Configurator::selectionChanged(QListViewItem *item)
 	
 	oclassName->insertStringList(XEObject::xGetPluginListNames());
 	oclassName->insertItem("disabled",0);
+	oclassName->insertItem("GSeparator",0);
 	oclassName->insertItem(icon->Info.className,0);
 	
 	//oclassName->setCurrentText(icon->Info.className);
@@ -1166,7 +1294,50 @@ void XEPlugin_Configurator::selectionChanged(QListViewItem *item)
 	oOverText->setText(icon->OverText);
 	oimgFileName->setText(icon->Images.imgFileName);
 	oimgFileArrow->setText(icon->Images.imgFileArrow);
+	oimgFileDrop->setText(icon->Images.imgFileDrop);
 	oonClickExec->setText(icon->Actions.onClickExec);
+	oonDropExec->setText(icon->Actions.onDropExec);
+	
+	// 0.29 read only action list
+
+	pXMLActionList->clear();
+	pXMLActionList->setEnabled(false);
+	for(int a=0;a<icon->Actions.ActionList.count();a++)
+	{
+		// now supporting only exec action
+		QString aAction=icon->Actions.ActionList.item(a).toElement().attribute("action");
+		QString aIcon=icon->Actions.ActionList.item(a).toElement().attribute("image");
+		if(aAction.isNull() || aAction=="")aAction="exec";
+		if(aIcon.isNull() || aIcon=="" )aIcon="run";
+		QString aInfo=icon->Actions.ActionList.item(a).toElement().attribute("info");
+		QString aExe=icon->Actions.ActionList.item(a).toElement().attribute("data");
+		if(aExe.isNull() || aExe=="" )continue;
+		if(aInfo.isNull() || aInfo=="" )aInfo=aExe;
+		QListViewItem	*item=new QListViewItem(
+			(QListView *)pXMLActionList);
+	
+		//	iconImg,icon->Info.Name,
+		//	iconImg,icon->Info.Group);
+		item->setText(0,aInfo);
+		item->setText(1,aIcon);
+		item->setText(2,aAction);
+		item->setText(3,aExe);
+		//item->setPixmap (0,iconImg);
+		pXMLActionList->insertItem(item);
+	}
+
+	// 0.29 read only dcop list
+	iconsListDCOP->clear();
+	iconsListDCOP->setEnabled(false);
+	for(int dcopi=0;dcopi<icon->Tasks.dcopName.count();dcopi++)
+	{
+		QListViewItem	*item=new QListViewItem(
+			(QListView *)iconsListDCOP);
+		item->setText(0,icon->Tasks.dcopName[dcopi]);
+		iconsListDCOP->insertItem(item);
+	}
+	
+	
 	/*
 	ioimgFileName->setIconSet(QIconSet(
 			KDEIconLoader.loadIcon(
@@ -1423,8 +1594,13 @@ void XEPlugin_Configurator::objectToolBar_clicked(int id)
 			}
 		}
 		break;
-
-		
+		case 100:
+		saveDefault();
+		break;
+		case 101:
+		qWarning("Not implemented yet");
+		//addIconWizard();
+		break;
 		
 		default:
 		break;
@@ -1453,39 +1629,74 @@ void XEPlugin_Configurator::xRemoveIcon()
 	if(iconsList->firstChild())
 		iconsList->setSelected(iconsList->firstChild() , true );
 }
+void XEPlugin_Configurator::saveDefault()
+{
+// before saving i will apply :)
+this->apply();
+//QString cfgPath=QDir::homeDirPath();
+//cfgPath+="/.kde/share/apps/kxdocker/kxdocker_conf.xml";
+QString cfgPath=::locateLocal("data","kxdocker/")+"kxdocker_conf.xml";
 
-
+// E' mooolto brutto che l'utente pu usare pi file di configurazione.
+// ce ne deve essere uno solo NASCOSTO!
+// in questo caso io commento tutto per coerenza in quello che credo
+// anche se lascio questo piccolo ed elegante controllino
+if(ActiveConfiguration->Engine.XMLConf!=cfgPath){
+KMessageBox::information(this,"Warning: you are saving in " + cfgPath +", that isn't your default config file ("+ActiveConfiguration->Engine.XMLConf+")");
+}
+ActiveConfiguration->Engine.XMLConf=cfgPath;
+xCfgWrite(cfgPath);
+//if(KMessageBox::warningYesNo(this,"Do you like to use this new xml configuration file at next KXDocker startup?","What XML configuration next time")==KMessageBox::Yes)
+//{
+//#ifndef ENABLE_FINAL
+//qWarning("Warning we are going to update the user configuration!");
+//#endif
+KConfig *cfg=KGlobal::config();
+cfg->setGroup("");
+cfg->writeEntry("KXDockerXMLConf",ActiveConfiguration->Engine.XMLConf);
+#ifndef ENABLE_FINAL
+KMessageBox::information(this,"you have to manually restart KXDocker to load new configuration","XML configuration Activation");
+#endif
+//}
+guiRefreshValues();
+}
 /*!
     \fn XEPlugin_Configurator::saveTo()
  */
 void XEPlugin_Configurator::saveTo()
 {
-	// before saving i will apply :)
-	this->apply();
-	
-	
-	KFileDialog fd(QString::null,QString::null,0,"openXMLConf",true);
-	QString cfgPath=fd.getSaveFileName(QString::null,QString::null,0,"Save KXDocker XML Configuration");
-	
-	if(cfgPath==NULL)
-	{
-		qWarning("cannot find kxdocker_conf.xml");
-		return;
-	}
-	ActiveConfiguration->Engine.XMLConf=cfgPath;
-	xCfgWrite(cfgPath);
-	
-	if(KMessageBox::warningYesNo(this,"Do you like to use this new xml configuration file at next KXDocker startup?","What XML configuration next time")==KMessageBox::Yes)
-	{
-	#ifndef ENABLE_FINAL
-		qWarning("Warning we are going to update the user configuration!");
-	#endif
-		KConfig *cfg=KGlobal::config();
-		cfg->setGroup("");
-		cfg->writeEntry("KXDockerXMLConf",ActiveConfiguration->Engine.XMLConf);
-		
-		KMessageBox::information 
+// before saving i will apply :)
+this->apply();
+/*
+KFileDialog fd(QString::null,QString::null,0,"openXMLConf",true);
+QString cfgPath=fd.getSaveFileName(QString::null,QString::null,0,"Save KXDocker XML Configuration");
+*/
+// Due soluzioni possibili: o apriamo la dir di configurazione di kxdocker,
+// oppure ActiveConfiguration->Engine.XMLConf
+//QString cfgDir=QDir::homeDirPath();
+//cfgDir+="/.kde/share/apps/kxdocker/";
+KFileDialog fd(QString::null,QString::null,0,i18n("openXMLConf"),true);
+QString cfgPath=fd.getSaveFileName(ActiveConfiguration->Engine.XMLConf/*cfgDir*/,QString::null,0,i18n("Save KXDocker XML Configuration"));
+if(cfgPath==NULL)
+{
+qWarning("cannot find kxdocker_conf.xml");
+return;
+}
+ActiveConfiguration->Engine.XMLConf=cfgPath;
+xCfgWrite(cfgPath);
+if(KMessageBox::warningYesNo(this,"Do you like to use this new xml configuration file at next KXDocker startup?","What XML configuration next time")==KMessageBox::Yes)
+{
+#ifndef ENABLE_FINAL
+qWarning("Warning we are going to update the user configuration!");
+#endif
+KConfig *cfg=KGlobal::config();
+cfg->setGroup("");
+cfg->writeEntry("KXDockerXMLConf",ActiveConfiguration->Engine.XMLConf);
+
+#ifndef ENABLE_FINAL
+KMessageBox::information 
 (this,"you have to manually restart KXDocker to load new configuration","XML configuration Activation");
+#endif
 	}
 	
 	guiRefreshValues();
@@ -1528,7 +1739,12 @@ void XEPlugin_Configurator::openCfg()
  */
 void XEPlugin_Configurator::addIcon()
 {
-	XSGObjectIcon *addedCfg=new XSGObjectIcon;
+			// 0.35
+	XEConfiguration *xEConfiguration=(XEConfiguration *)XEObject::xGetConfiguration();
+	if(xEConfiguration==NULL)qWarning(name());
+	XSGObjectIcon *addedCfg=xEConfiguration->iconAdd();
+
+//	XSGObjectIcon *addedCfg=new XSGObjectIcon;
 //	addedCfg->Tasks.PopupMenu=new KPopupMenu();
 	addedCfg->Tasks.PopupMenu=NULL;
 	addedCfg->PluginPopupMenu=NULL;
@@ -1551,12 +1767,17 @@ void XEPlugin_Configurator::addIcon()
 	addedCfg->Info.Name=b;
 	addedCfg->Info.Group=b;
 	addedCfg->Actions.onClickExec="";
+	addedCfg->Actions.onDropExec="";
 	addedCfg->OverText=b;
 	addedCfg->Images.imgFileName="default";
 	
 	addedCfg->Tasks.ShowThumbnail=0;
 	addedCfg->Tasks.TaskInfo=NULL;
-	
+	//0.29
+	addedCfg->Tasks.dcopReady=0;
+		// 0.33
+		addedCfg->Tasks.forceRunning=0;
+
 	xGDocker->xEventTaskAppend(ActiveConfiguration->ObjectsIcons.count()-1);
 	
 	guiRefreshValues();
@@ -1583,6 +1804,19 @@ void XEPlugin_Configurator::downIcon()
 		int idx1=ActiveConfiguration->ObjectsIcons.find(
 			ActiveConfiguration->RollingIcons.at(idr)
 			);
+		// 0.33
+		// test if it's a separator
+		if(idx1>=0)
+		{
+			if(ActiveConfiguration->ObjectsIcons.at(idx1)->Info.className=="GSeparator")
+			{
+				idr++;
+				int idx1=ActiveConfiguration->ObjectsIcons.find(
+				ActiveConfiguration->RollingIcons.at(idr)
+			);
+
+			}
+		}
 		if(idx>=0 && idx1>=0)
 		{
 			ActiveConfiguration->ObjectsIcons.replace
@@ -1640,6 +1874,22 @@ void XEPlugin_Configurator::upIcon()
 		int idx1=ActiveConfiguration->ObjectsIcons.find(
 			ActiveConfiguration->RollingIcons.at(idr)
 			);
+		// 0.33
+		// test if it's a separator
+		if(idx1>=0)
+		{
+			if(ActiveConfiguration->ObjectsIcons.at(idx1)->Info.className=="GSeparator")
+			{
+				idr--;
+				if(idr>=0)
+				idx1=ActiveConfiguration->ObjectsIcons.find(
+				ActiveConfiguration->RollingIcons.at(idr)
+				);
+				else return;
+
+			}
+		}
+
 		if(idx>=0 && idx1>=0)
 		{
 			ActiveConfiguration->ObjectsIcons.replace
@@ -1682,14 +1932,16 @@ void XEPlugin_Configurator::upIcon()
  */
 void XEPlugin_Configurator::apply()
 {
+#ifndef ENABLE_FINAL
 	KMessageBox::information 
 (this,"A few parameters cannot be applyed at this time.\nRememeber to save and enable your configuration.\nYou can do this by saving your new configuration.","XML configuration Activation");
-
+#endif
 
 	// saving data
 	ActiveConfiguration->Engine.AndZoomCache=AndZoomCache->value();
 #ifdef ENABLE_SPECIALENGINE2
 	ActiveConfiguration->Engine.InterpolationValue=InterpolationValue->value();
+	if(ActiveConfiguration->Engine.InterpolationValue<1)ActiveConfiguration->Engine.InterpolationValue=1;
 #endif    
 
 	ActiveConfiguration->Engine.MaxIconsShowed=MaxIconsShowed->value(); 
@@ -1713,7 +1965,10 @@ void XEPlugin_Configurator::apply()
 	ActiveConfiguration->Icons.Horiz=Horiz->value();
 	ActiveConfiguration->Icons.Raise=Raise->value();
 	ActiveConfiguration->Icons.Separation=Separation->value();
-	ActiveConfiguration->Icons.Size=Size->value();
+	ActiveConfiguration->Icons.SizePrefer=Size->value();
+	// 0.33
+	if(!ActiveConfiguration->AutoResize)ActiveConfiguration->Icons.Size=ActiveConfiguration->Icons.SizePrefer;
+	//0.30
 	ActiveConfiguration->Icons.SizeBig=SizeBig->value();
 	ActiveConfiguration->Matrix.Design=Design->currentText();
 	
@@ -1721,8 +1976,19 @@ void XEPlugin_Configurator::apply()
 	ActiveConfiguration->Window.HideTimeout=HideTimeout->value();
 	ActiveConfiguration->Window.TopForce=TopForce->value();
 	ActiveConfiguration->Window.LeftForce=LeftForce->value();
-
 	
+	ActiveConfiguration->Window.HeightDesktop=HeightDesktop->value();
+	if(AutoSave->isChecked())ActiveConfiguration->AutoSave=1;
+	else ActiveConfiguration->AutoSave=0;
+	if(AutoResize->isChecked())ActiveConfiguration->AutoResize=1;
+	else ActiveConfiguration->AutoResize=0;
+
+
+
+	if(FastHide->isChecked())ActiveConfiguration->Window.FastHide=1;
+	else ActiveConfiguration->Window.FastHide=0;
+
+	ActiveConfiguration->Theme.Background.Desaturate=imgBackground_Desaturate->value();
 	if(RaiseOnEvents->isChecked())ActiveConfiguration->Window.RaiseOnEvents=true;
 	else ActiveConfiguration->Window.RaiseOnEvents=false;
 	ActiveConfiguration->Window.SendToForgroundTimeout=SendToForgroundTimeout->value();
@@ -1760,9 +2026,18 @@ void XEPlugin_Configurator::apply()
 	{
 		xGDocker->reloadIcon(i);
 	}
+	
+	// Engine with autoresize and dynamic update matrix
+	// 25 Marzo 2005
+	// 0.30
+	//XEMatrix *XMatrix=(XEMatrix *)XEObject::xGetMatrix();
+	
+	//XMatrix->xUpdateMatrix();
+	xGDocker->xUpdateSense();
 	// new Engine 11 05 2004
 	// change background must came at end
-	xGDocker->changeBackground(ActiveConfiguration->Theme.BackgroundPath);
+	//xGDocker->changeBackground(ActiveConfiguration->Theme.BackgroundPath);
+	//xGDocker->xMoveWidgetCenter();
 }
 
 
@@ -1971,7 +2246,9 @@ void XEPlugin_Configurator::alias_selectionChanged(QListViewItem *item)
 	aOverText->setText(icon->OverText);
 	aimgFileName->setText(icon->Images.imgFileName);
 	aimgFileArrow->setText(icon->Images.imgFileArrow);
+	aimgFileDrop->setText(icon->Images.imgFileDrop);
 	aonClickExec->setText(icon->Actions.onClickExec);
+	aonDropExec->setText(icon->Actions.onDropExec);
 	
 	iaimgFileName->setIcon(icon->Images.imgFileName);
 }
@@ -2360,12 +2637,62 @@ void XEPlugin_Configurator::apply_plugins()
 void XEPlugin_Configurator::refreshPluginscfg(XSGObjectIcon *icon, KListView *list)
 {
 	list->clear();
+	disconnect(this, SIGNAL(xPluginRunConfigurator()));
+
+	connect(this, SIGNAL(xPluginRunConfigurator()),
+		XEObject::xFindObject(icon->Info.className),
+		SLOT(xRunConfigurator()));
+	
+	oPluginName->setText("");
+	oPluginVersion->setText("");
+	oPluginDate->setText("");
+	oPluginAuthor->setText("");
+	oPluginAuthorMail->setText("");
+	oPluginUrlDownload->setText("");
+	oPluginUrlDocumentation->setText("");
+	oPluginUrlUpdate->setText("");
+	disconnect(this, SIGNAL(xFetchGetInfo(QStringList &)),
+		XEObject::xFindObject(icon->Info.className),
+		SLOT(xGetInfo(QStringList &)));
+	if(
+	connect(this, SIGNAL(xFetchGetInfo(QStringList &)),
+		XEObject::xFindObject(icon->Info.className),
+		SLOT(xGetInfo(QStringList &))))
+	{
+		QStringList getInfo;
+		xFetchGetInfo(getInfo);
+		int ivs=0;
+		if(getInfo.count()>ivs)oPluginName->setText(getInfo[ivs]);
+		ivs++;
+		if(getInfo.count()>ivs)oPluginVersion->setText(getInfo[ivs]);
+		ivs++;
+		if(getInfo.count()>ivs)oPluginDate->setText(getInfo[ivs]);
+		ivs++;
+		if(getInfo.count()>ivs)oPluginAuthor->setText(getInfo[ivs]);
+		ivs++;
+		if(getInfo.count()>ivs)oPluginAuthorMail->setText(getInfo[ivs]);
+		ivs++;
+		if(getInfo.count()>ivs)oPluginUrlDownload->setText(getInfo[ivs]);
+		ivs++;
+		if(getInfo.count()>ivs)oPluginUrlDocumentation->setText(getInfo[ivs]);
+		ivs++;
+		if(getInfo.count()>ivs)oPluginUrlUpdate->setText(getInfo[ivs]);
+
+	}
+	
+	
 	#ifndef ENABLE_FINAL
 	qWarning(icon->Info.className);
 	#endif
 	connect(this, SIGNAL(xGetParameterList(QStringList *)),
 		XEObject::xFindObject(icon->Info.className),
 		SLOT(xGetParameterList(QStringList *)));
+	/*
+	connect(this, SIGNAL(),
+		XEObject::xFindObject(icon->Info.className),
+		SLOT(xGetParameterList(QStringList *)));
+	*/	
+		
 	QStringList a;
 	a.clear();
 	pXMLConf->clear();
@@ -2440,7 +2767,13 @@ void XEPlugin_Configurator::apply_objectsplugin()
  */
 void XEPlugin_Configurator::add_alias()
 {
-	XSGObjectIcon *addedCfg=new XSGObjectIcon;
+			// 0.35
+	XEConfiguration *xEConfiguration=(XEConfiguration *)XEObject::xGetConfiguration();
+	if(xEConfiguration==NULL)qWarning(name());
+
+	XSGObjectIcon *addedCfg=xEConfiguration->iconAdd();
+
+//	XSGObjectIcon *addedCfg=new XSGObjectIcon;
 	XSCfgMatchIcons *addedMatch=new XSCfgMatchIcons;
 	addedMatch->Icon=addedCfg;
 	
@@ -2467,12 +2800,17 @@ void XEPlugin_Configurator::add_alias()
 	addedCfg->Info.Name=b;
 	addedCfg->Info.Group=b;
 	addedCfg->Actions.onClickExec="";
+	addedCfg->Actions.onDropExec="";
 	addedCfg->OverText=b;
 	addedCfg->Images.imgFileName="default";
 	
 	addedCfg->Tasks.ShowThumbnail=0;
 	addedCfg->Tasks.TaskInfo=NULL;
-	
+	//0.29
+	addedCfg->Tasks.dcopReady=0;
+		// 0.33
+		addedCfg->Tasks.forceRunning=0;
+
 	guiRefreshValues();
 	
 	if(aliasList->lastChild())
@@ -2517,37 +2855,77 @@ void XEPlugin_Configurator::slot_aSystem_textChanged ( const QString & newt)
  */
 void XEPlugin_Configurator::create_about(QVBox	*vpage1)
 {
-    new QLabel( "Welcome to KXDocker", vpage1);
-    QVGroupBox *gvabout=new QVGroupBox( "About:",vpage1);
+    new QLabel(i18n("Welcome to KXDocker"), vpage1);
+    QVGroupBox *gvabout=new QVGroupBox(i18n("About:"),vpage1);
     QString a;
-    a=QString("You are using KXDocker Version %1").arg(KXDOCKERVERSION);
+    a=QString(i18n("You are using KXDocker Version"));
+    a=a+QString(" %1 ").arg(KXDOCKERVERSION);
+    a=a+QString(i18n("released on"));
+    a=a+QString(" %1 ").arg(KXDOCKERDATE);
     new QLabel(a, gvabout);
-    a=QString("KXDocker is an innovative docker for KDE 3.2.x");
+    a=QString(i18n("KXDocker is an innovative docker for KDE 3.x.x"));
+    /*
+ KXDocker is an innovative docker for KDE it's like Mac OSX Docker but more powerfull. 
+ KXDocker target is to implement a new Docker idea to improve usability of Linux Desktops. 
+ KXDocker is a VERY big project where the goal is desktop integration with Linux Operative System. 
+ KXDocker is not only an "old school docker" !. 
+    */
+    
     new QLabel(a, gvabout);
-    a=QString("KXDocker is a XIA Projects product");
+    a=QString(i18n("KXDocker is a XIA Projects product"));
     new QLabel(a, gvabout);
     a=QString("http://www.xiaprojects.com");
     new QLabel(a, gvabout);
-    gvabout=new QVGroupBox( "Developers:",vpage1);
+
+    gvabout=new QVGroupBox(i18n("Many thanks to contributors:"),vpage1);
     
-    a=QString("Main developer: Stefano Zingarini");
+    a=QString("Lucio");
     new QLabel(a, gvabout);
-    a=QString("Man thanks to other minor developers:");
+    a=QString("Magilla");
     new QLabel(a, gvabout);
-    a=QString("Saurabh");
+    a=QString("Michel");
     new QLabel(a, gvabout);
-    a=QString("Thomas");
+    a=QString("Eric");
     new QLabel(a, gvabout);
+QPushButton *pab=new QPushButton(i18n("About KXDocker (click on the tray, here not ready yet)"),vpage1);
+//connect(pab,SIGNAL(clicked()),XEObject::xFindObject("xTray"),SLOT(xAbout()));
+
+
+/*
+    gvabout=new QVGroupBox(i18n("Developer Team:"),vpage1);
+    a=QString(i18n("Main developer"));
+    a=a+QString(": Stefano Zingarini stefano@xiaprojects.com");
+    new QLabel(a, gvabout);
+    a=QString(i18n("Many thanks to other minor developers:"));
+    new QLabel(a, gvabout);
+    
+    QGrid	*griglia2=new QGrid(2,gvabout);
+    a=QString("Bruno");
+    new QLabel(a, griglia2);
     a=QString("Filip");
-    new QLabel(a, gvabout);
-    gvabout=new QVGroupBox( "Read here:",vpage1);
+    new QLabel(a, griglia2);
+    a=QString("Lucio");
+    new QLabel(a, griglia2);
+    a=QString("Magilla");
+    new QLabel(a, griglia2);
+    a=QString("Thomas");
+    new QLabel(a, griglia2);
+    a=QString("Saurabh");
+    new QLabel(a, griglia2);
+    a=QString("Vagninu");
+    new QLabel(a, griglia2);
+*/
+    gvabout=new QVGroupBox(i18n("Read here:"),vpage1);
+    
+    a=QString(i18n("Configurator Version"));
+    a=a+QString(" %1\n").arg(KX_CFG_VERSION);
+    a=a+QString(i18n("If you update any parameter remeber: YOU MUST click on APPLY Button on top!"));
     
-    a=QString("Configurator Version 0.6\nIf you update any parameter remeber: YOU MUST click on APPLY Button on top!");
     new QLabel(a, gvabout);
     
-    gvabout=new QVGroupBox( "KXDocker compilation:",vpage1);
+    gvabout=new QVGroupBox(i18n("KXDocker compilation options:"),vpage1);
     QGrid	*griglia=new QGrid(2,gvabout);
-    a=QString("you have enabled this switch at compile time:");
+    a=QString(i18n("you have enabled this switch at compile time:"));
     new QLabel(a, griglia);
     a=QString("");
     new QLabel(a, griglia);
@@ -2642,3 +3020,84 @@ void XEPlugin_Configurator::removePlugin()
 	KMessageBox::information 
 (this,"you have to manually save and restart KXDocker apply this update","XML configuration Activation");
 }
+
+
+/*!
+    \fn XEPlugin_Configurator::slot_aOnDropExec_textChanged(const QString&)
+ */
+void XEPlugin_Configurator::slot_aOnDropExec_textChanged(const QString &newt)
+{
+	if(LastAlias!=NULL && ActiveConfiguration->Plugins.Matches.find(LastAlias)>=0)
+	{
+		// ok i hope it will exists
+		LastAlias->Icon->Actions.onDropExec=newt;
+	
+	}
+}
+
+
+/*!
+    \fn XEPlugin_Configurator::slot_oOnDropExec_textChanged(const QString&)
+ */
+void XEPlugin_Configurator::slot_oOnDropExec_textChanged(const QString &newt)
+{
+	if(LastIcon!=NULL && ActiveConfiguration->RollingIcons.find(LastIcon)>=0)
+	{
+		// ok i hope it will exists
+		LastIcon->Actions.onDropExec=newt;
+	}
+}
+
+
+/*!
+    \fn XEPlugin_Configurator::slot_oImgArrow_textChanged ( const QString &)
+ */
+void XEPlugin_Configurator::slot_oImgDrop_textChanged ( const QString &newt)
+{
+	if(LastIcon!=NULL && ActiveConfiguration->RollingIcons.find(LastIcon)>=0)
+	{
+		// ok i hope it will exists
+		if(LastIcon->Images.imgFileDrop==newt)return;
+		LastIcon->Images.imgFileDrop=newt;
+		// ok now we have to check if it's displayed:
+		int idx=ActiveConfiguration->ObjectsIcons.find(LastIcon);
+		if(idx>=0)
+		{
+			// refresh icon on the docker
+			xGDocker->reloadIcon(idx);
+		}
+	}
+}
+
+
+/*!
+    \fn XEPlugin_Configurator::slot_aImgDrop_textChanged (const QString &)
+ */
+void XEPlugin_Configurator::slot_aImgDrop_textChanged (const QString &newt)
+{
+	if(LastAlias!=NULL && ActiveConfiguration->Plugins.Matches.find(LastAlias)>=0)
+	{
+		// ok i hope it will exists
+		LastAlias->Icon->Images.imgFileDrop=newt;
+	
+	}
+}
+
+
+/*!
+    \fn XEPlugin_Configurator::xGetInfo(QStringList &)
+ */
+void XEPlugin_Configurator::xGetInfo(QStringList &)
+{
+    /// @todo implement me
+}
+
+
+/*!
+    \fn XEPlugin_Configurator::xRunCfg()
+ */
+void XEPlugin_Configurator::xRunCfg()
+{
+	qWarning("Running plugin configuration...");
+	this->xPluginRunConfigurator();
+}
