@@ -24,6 +24,11 @@
 #include "xgicon.h"
 
 #include <kpopupmenu.h>
+#include <kapplication.h>
+#include <dcopobject.h>
+#include <dcopclient.h>
+#include <dcopref.h>
+
 
 #include <qpixmap.h>
 #include <qimage.h>
@@ -31,8 +36,12 @@
 #include <netwm.h>
 #include <stdlib.h>
 
+#include <xeplugin_animator.h>
+
 #include <kxdocker_setup_sources.h>
 
+//#undef ENABLE_FINAL
+
 XEPlugin_TaskManager::XEPlugin_TaskManager(QObject *parent, const char *name)
  : QObject(parent, name)
 {
@@ -48,6 +57,28 @@ XEPlugin_TaskManager::XEPlugin_TaskManager(QObject *parent, const char *name)
 	connect(KDETaskManager, SIGNAL(taskActivated(Task*)), this, SLOT(taskActivated(Task*)) );
 	XEObject::xPluginAdd(this);
 //	LastThumbnailUpdate=NULL;
+	//0.29
+	// dcop
+	dcopPollingTimeout=10;
+	//dcopClient = kapp->dcopClient();
+	dcopClient =new DCOPClient();
+	dcopClient->attach();
+  connect
+    (
+     dcopClient,
+     SIGNAL(applicationRegistered(const QCString &)),
+     SLOT(dcop_applicationRegistered(const QCString &))
+    );
+
+  connect
+    (
+     dcopClient,
+     SIGNAL(applicationRemoved(const QCString &)),
+     SLOT(dcop_applicationRemoved(const QCString &))
+    );
+
+	dcopClient->setNotifications(true);
+
 }
 
 
@@ -88,7 +119,7 @@ void XEPlugin_TaskManager::xSetup()
 #ifndef ENABLE_FINAL
 	qWarning("xeplugin_taskmanager.cpp 81");
 #endif
-	for(int i=0;i<ActiveConfiguration->Plugins.Plugin.count(); i++)
+	for(uint i=0;i<ActiveConfiguration->Plugins.Plugin.count(); i++)
 	{
 #ifndef ENABLE_FINAL
 		qWarning(ActiveConfiguration->Plugins.Plugin.at(i)->Info.Name);
@@ -142,7 +173,7 @@ ActiveConfiguration->Plugins.Plugin.at(i)->xmlConfiguration.item(0).toElement().
 			QStringList	a;
 			// Creating the Attributes via the standard plugin interface
 			xGetParameterList(&a);
-			for(int istoringXML=0;istoringXML<a.count();istoringXML++)
+			for(uint istoringXML=0;istoringXML<a.count();istoringXML++)
 			{
 				QString returnValue;
 				xGetParameter(a[istoringXML],returnValue);
@@ -176,6 +207,8 @@ void XEPlugin_TaskManager::xStart()
     {
     	taskAdded(task);
     }
+    
+    dcopPolling();
 }
 
 
@@ -202,13 +235,13 @@ void XEPlugin_TaskManager::currentDesktopChanged(int desktop)
 	if(showWindowsOnlyFromThisDesktop)
 	{
 		// we have to remove the other window
-		for(int i =0; i<ActiveConfiguration->ObjectsIcons.count();i++)
+		for(uint i =0; i<ActiveConfiguration->ObjectsIcons.count();i++)
 		{
 			// removing
 			usleep(ActiveConfiguration->Engine.SleepThreads);
 			if(ActiveConfiguration->ObjectsIcons.at(i)->Info.className!=name())continue;
 			int isHere=0;
-			for(int k=0;k<ActiveConfiguration->ObjectsIcons.at(i)->Tasks.Proces.count();k++)
+			for(uint k=0;k<ActiveConfiguration->ObjectsIcons.at(i)->Tasks.Proces.count();k++)
 			{
 				Task *t=(Task *)ActiveConfiguration->ObjectsIcons.at(i)->Tasks.Proces.at(k);
 				if(t->desktop()==desktop)
@@ -234,11 +267,11 @@ void XEPlugin_TaskManager::currentDesktopChanged(int desktop)
 		if(cn=="GSeparator")
 			xGDocker->iconRemove(ActiveConfiguration->ObjectsIcons.count()-1,1);
 	}
-		for(int i =0; i<ActiveConfiguration->RollingIcons.count();i++)
+		for(uint i =0; i<ActiveConfiguration->RollingIcons.count();i++)
 		{
 			// adding
 			usleep(ActiveConfiguration->Engine.SleepThreads);
-			for(int k=0;k<ActiveConfiguration->RollingIcons.at(i)->Tasks.Proces.count();k++)
+			for(uint k=0;k<ActiveConfiguration->RollingIcons.at(i)->Tasks.Proces.count();k++)
 			{
 				Task *t=(Task *)ActiveConfiguration->RollingIcons.at(i)->Tasks.Proces.at(k);
 				if(t->desktop()==desktop)
@@ -250,7 +283,7 @@ void XEPlugin_TaskManager::currentDesktopChanged(int desktop)
 						qWarning("Will be showed:");
 						qWarning(t->name());
 #endif
-	if(ActiveConfiguration->ObjectsIcons.count()>=ActiveConfiguration->Engine.MaxIconsShowed)return;
+	if(ActiveConfiguration->ObjectsIcons.count()>=(uint)ActiveConfiguration->Engine.MaxIconsShowed)return;
 	if(autoAddSeparator)
 	{
 		QString cn=ActiveConfiguration->ObjectsIcons.at(ActiveConfiguration->ObjectsIcons.count()-1)->Info.className;
@@ -302,17 +335,23 @@ void XEPlugin_TaskManager::taskAdded(Task *t)
 	{
 		//qWarning("showGroupWindows!=0 we will group windows");
 	// checking for window title ==
-	for(int i =0; i<ActiveConfiguration->ObjectsIcons.count();i++)
+	//for(uint i =0; i<ActiveConfiguration->ObjectsIcons.count();i++)
+	//0.29
+
+
+if(WindowTitle!=""){
+	for(uint i =0; i<ActiveConfiguration->RollingIcons.count();i++)
 	{
 		// (martind@pirack.com) Avoid null pointer when (e.g.) opening the configuration dialog for screensaver
 		if (ActiveConfiguration->RollingIcons.at(i) != NULL)
 		{
 		  usleep(ActiveConfiguration->Engine.SleepThreads);
-		  for(int k=0;k<ActiveConfiguration->RollingIcons.at(i)->Tasks.WindowTitle.count();k++)
+		  for(uint k=0;k<ActiveConfiguration->RollingIcons.at(i)->Tasks.WindowTitle.count();k++)
 		  {
 #ifndef ENABLE_FINAL
 		    qWarning(ActiveConfiguration->RollingIcons.at(i)->Tasks.WindowTitle[k]);
 #endif
+			if(ActiveConfiguration->RollingIcons.at(i)->Tasks.WindowTitle[k]=="")continue;
 			  if(ActiveConfiguration->RollingIcons.at(i)->Tasks.WindowTitle[k]==WindowTitle)
 			  {
 				  ActiveConfiguration->RollingIcons.at(i)->Tasks.Proces.append(t);
@@ -326,17 +365,29 @@ void XEPlugin_TaskManager::taskAdded(Task *t)
 #ifndef ENABLE_FINAL
 	qWarning("Test find Title ");
 #endif
-	for(int i =0; i<ActiveConfiguration->RollingIcons.count();i++)
+	for(uint i =0; i<ActiveConfiguration->RollingIcons.count();i++)
 	{
 		usleep(ActiveConfiguration->Engine.SleepThreads);
-		for(int k=0;k<ActiveConfiguration->RollingIcons.at(i)->Tasks.WindowTitle.count();k++)
+		for(uint k=0;k<ActiveConfiguration->RollingIcons.at(i)->Tasks.WindowTitle.count();k++)
 		{
 			QString pippo=ActiveConfiguration->RollingIcons.at(i)->Tasks.WindowTitle[k];
+			if(pippo=="")continue;
 			if(WindowTitle.startsWith(pippo,false))
 			{
 #ifndef ENABLE_FINAL
 				qWarning("String OK");
 				qWarning(pippo);
+#endif
+				ActiveConfiguration->RollingIcons.at(i)->Tasks.Proces.append(t);
+				ActiveConfiguration->RollingIcons.at(i)->Tasks.TaskInfo=(void *)t;
+				gotTaskInCache(ActiveConfiguration->RollingIcons.at(i));
+				return;
+			}
+			if(WindowTitle.endsWith(pippo,false))
+			{
+#ifndef ENABLE_FINAL
+				qWarning("String OK");
+				qWarning(pippo);
 #endif
 				ActiveConfiguration->RollingIcons.at(i)->Tasks.Proces.append(t);
 				ActiveConfiguration->RollingIcons.at(i)->Tasks.TaskInfo=(void *)t;
@@ -345,15 +396,19 @@ void XEPlugin_TaskManager::taskAdded(Task *t)
 			}
 		}
 	}
+}
 #ifndef ENABLE_FINAL
 	qWarning("Test == Taskname");
 #endif
-
-		for(int i =0; i<ActiveConfiguration->RollingIcons.count();i++)
+if(TaskName!="")
+{
+		for(uint i =0; i<ActiveConfiguration->RollingIcons.count();i++)
 		{
 			usleep(ActiveConfiguration->Engine.SleepThreads);
-			for(int k=0;k<ActiveConfiguration->RollingIcons.at(i)->Tasks.TaskName.count();k++)
+			for(uint k=0;k<ActiveConfiguration->RollingIcons.at(i)->Tasks.TaskName.count();k++)
 			{
+			if(ActiveConfiguration->RollingIcons.at(i)->Tasks.TaskName[k]=="")continue;
+
 				if(ActiveConfiguration->RollingIcons.at(i)->Tasks.TaskName[k]==TaskName)
 				{
 					ActiveConfiguration->RollingIcons.at(i)->Tasks.Proces.append(t);
@@ -363,15 +418,20 @@ void XEPlugin_TaskManager::taskAdded(Task *t)
 				}
 			}
 		}
+}
 	#ifndef ENABLE_FINAL
 		qWarning("Test == Class");
 	#endif
-		
-		for(int i =0; i<ActiveConfiguration->RollingIcons.count();i++)
+if(ClassName!="")
+{
+		for(uint i =0; i<ActiveConfiguration->RollingIcons.count();i++)
 		{
 			usleep(ActiveConfiguration->Engine.SleepThreads);
-			for(int k=0;k<ActiveConfiguration->RollingIcons.at(i)->Tasks.ClassName.count();k++)
+			for(uint k=0;k<ActiveConfiguration->RollingIcons.at(i)->Tasks.ClassName.count();k++)
 			{
+
+				if(ActiveConfiguration->RollingIcons.at(i)->Tasks.ClassName[k]=="")continue;
+
 				if(ActiveConfiguration->RollingIcons.at(i)->Tasks.ClassName[k]==ClassName)
 				{
 					ActiveConfiguration->RollingIcons.at(i)->Tasks.Proces.append(t);
@@ -382,12 +442,19 @@ void XEPlugin_TaskManager::taskAdded(Task *t)
 			}
 		}
 	}
+}
 	// ok, we havent find it...
 	// making new configuration
-	if(ActiveConfiguration->ObjectsIcons.count()>=ActiveConfiguration->Engine.MaxIconsShowed)return;
+	if(ActiveConfiguration->ObjectsIcons.count()>=(uint)ActiveConfiguration->Engine.MaxIconsShowed)return;
 	
-	
-	XSGObjectIcon *addedCfg=new XSGObjectIcon;
+	// 0.35
+	//XSGObjectIcon *addedCfg=new XSGObjectIcon;
+	XEConfiguration *xEConfiguration=(XEConfiguration *)XEObject::xGetConfiguration();
+	if(xEConfiguration==NULL)qWarning(name());
+	XSGObjectIcon *addedCfg=xEConfiguration->iconAdd();
+
+
+
 //	addedCfg->Tasks.PopupMenu=new KPopupMenu();
 	addedCfg->Tasks.PopupMenu=NULL;
 	addedCfg->PluginPopupMenu=NULL;
@@ -403,6 +470,9 @@ void XEPlugin_TaskManager::taskAdded(Task *t)
 	addedCfg->Info.Name=TaskName;
 	addedCfg->Info.Group=TaskName;
 	addedCfg->Actions.onClickExec=TaskName;
+	addedCfg->Actions.onDropExec=TaskName;
+	addedCfg->Actions.onDropExec+=" \"%1\"";
+	
 	addedCfg->OverText=TaskName;
 	addedCfg->Images.imgFileName=TaskName;
 	addedCfg->Tasks.WindowTitle.append(WindowTitle);
@@ -412,15 +482,24 @@ void XEPlugin_TaskManager::taskAdded(Task *t)
 	addedCfg->Tasks.Thumbnail=t->thumbnail();
 	addedCfg->Tasks.TaskInfo=(void *)t;
 	addedCfg->Tasks.Proces.append(t);
+	//0.29
+	addedCfg->Tasks.dcopName.append(TaskName);
+	// TODO better dcop notification support
+	addedCfg->Tasks.dcopReady=0;
+	addedCfg->Tasks.forceRunning=0;
+	addedCfg->Tasks.dcopNewWindow="dcop "+TaskName+" "+TaskName+"-mainwindow#1 restore";
+	addedCfg->Tasks.dcopClose="dcop "+TaskName+" "+TaskName+"-mainwindow#1 close";
+	addedCfg->Tasks.dcopRestore="dcop "+TaskName+" "+TaskName+"-mainwindow#1 restore";
+	
 	
 	// new engine 0.13 match on custom entry
 #ifndef ENABLE_FINAL
 	qWarning("Test == TITLE (custom entry)");
 #endif
-	for(int i=0; i<ActiveConfiguration->Plugins.Matches.count();i++)
+	for(uint i=0; i<ActiveConfiguration->Plugins.Matches.count();i++)
 	{
 		usleep(ActiveConfiguration->Engine.SleepThreads);
-		for(int k=0;k<ActiveConfiguration->Plugins.Matches.at(i)->Icon->Tasks.WindowTitle.count();k++)
+		for(uint k=0;k<ActiveConfiguration->Plugins.Matches.at(i)->Icon->Tasks.WindowTitle.count();k++)
 		{
 #ifndef ENABLE_FINAL
 			qWarning(ActiveConfiguration->Plugins.Matches.at(i)->Icon->Tasks.WindowTitle[k]);
@@ -439,14 +518,27 @@ void XEPlugin_TaskManager::taskAdded(Task *t)
 		}
 	}
 	
-	for(int i=0; i<ActiveConfiguration->Plugins.Matches.count();i++)
+	for(uint i=0; i<ActiveConfiguration->Plugins.Matches.count();i++)
 	{
 		usleep(ActiveConfiguration->Engine.SleepThreads);
-		for(int k=0;k<ActiveConfiguration->Plugins.Matches.at(i)->Icon->Tasks.WindowTitle.count();k++)
+		for(uint k=0;k<ActiveConfiguration->Plugins.Matches.at(i)->Icon->Tasks.WindowTitle.count();k++)
 		{
 #ifndef ENABLE_FINAL
 			qWarning(ActiveConfiguration->Plugins.Matches.at(i)->Icon->Tasks.WindowTitle[k]);
 #endif
+			if(ActiveConfiguration->Plugins.Matches.at(i)->Icon->Tasks.WindowTitle[k]=="")continue;
+			if(WindowTitle.startsWith(
+				ActiveConfiguration->Plugins.Matches.at(i)->Icon->Tasks.WindowTitle[k])
+			)
+			{
+				// Got it
+#ifndef ENABLE_FINAL
+				qWarning("match!");
+#endif
+				clonate(addedCfg,ActiveConfiguration->Plugins.Matches.at(i)->Icon);
+				//return;
+				break;
+			}
 			if(WindowTitle.endsWith(
 				ActiveConfiguration->Plugins.Matches.at(i)->Icon->Tasks.WindowTitle[k])
 			)
@@ -500,8 +592,8 @@ void XEPlugin_TaskManager::taskAdded(Task *t)
 		XGIcon *newIcon=xGDocker->getObjectIcon(ActiveConfiguration->ObjectsIcons.count()-1);
 		if(newIcon->xImgSource==defaulImage)
 		{
-			qWarning("You don't have configured the right PNG for this window I will generate new one.");
-			bool isStaticIcon;
+//			qWarning("You don't have configured the right PNG for this window I will generate new one.");
+			//bool isStaticIcon;
 			newIcon->xImgSource=t->pixmap();
 			newIcon->xImgOriginal=newIcon->xImgSource;
 			newIcon->cachePurge();
@@ -514,7 +606,9 @@ void XEPlugin_TaskManager::taskAdded(Task *t)
 	
 	if(ActiveConfiguration->Icons.EnableThumbnail)
 	{
-		t->setThumbnailSize(128);
+		// 0.32
+		t->setThumbnailSize(ActiveConfiguration->Icons.SizeBig);
+		//t->setThumbnailSize(128);
 		t->updateThumbnail(2000);
 	}
 }
@@ -537,24 +631,45 @@ void XEPlugin_TaskManager::taskRemoved(Task*t)
 /*!
     \fn XEPlugin_TaskManager::startupAdded(Startup*)
  */
-void XEPlugin_TaskManager::startupAdded(Startup*)
+void XEPlugin_TaskManager::startupAdded(Startup* newApp)
 {
     /// @todo implement me
 #ifndef ENABLE_FINAL
     qWarning("TaskManager::StartupAdd()");
 #endif
+
+	QString iname=newApp->text();
+	XEPlugin_Animator *xAnimator=(XEPlugin_Animator *)XEObject::xFindObject("xAnimator");
+	if(!xAnimator)return;
+	for(uint i=0;i<ActiveConfiguration->ObjectsIcons.count();i++)
+	{
+		if(ActiveConfiguration->ObjectsIcons.at(i)->Info.Name==iname)
+		{
+			XGIcon *theIcon=xGDocker->getObjectIcon(i);
+			if(!theIcon)return;
+			xAnimator->xStartAnimate(theIcon);
+			return;
+		}
+	}
 }
 
 
 /*!
     \fn XEPlugin_TaskManager::startupRemoved(Startup*)
  */
-void XEPlugin_TaskManager::startupRemoved(Startup*)
+void XEPlugin_TaskManager::startupRemoved(Startup* newApp)
 {
     /// @todo implement me
 #ifndef ENABLE_FINAL
     qWarning("TaskManager::StartupRemoved()");
 #endif
+
+	QString iname=newApp->text();
+	XEPlugin_Animator *xAnimator=(XEPlugin_Animator *)XEObject::xFindObject("xAnimator");
+	if(!xAnimator)return;
+
+	xAnimator->xStopAnimate();
+
 }
 
 
@@ -566,7 +681,7 @@ void XEPlugin_TaskManager::removeIcon(Task *t)
 #ifndef ENABLE_FINAL
 qWarning("taskmanager polling");
 #endif
-    for(int i=0;i<ActiveConfiguration->RollingIcons.count();i++)
+    for(uint i=0;i<ActiveConfiguration->RollingIcons.count();i++)
     {
 #ifndef ENABLE_FINAL
 qWarning("xeplugin_taskmanger.cpp:347");
@@ -649,7 +764,7 @@ void XEPlugin_TaskManager::thumbnailChanged(Task *t)
 #endif
 	if(t==NULL)return;
 
-    for(int i=0;i<ActiveConfiguration->ObjectsIcons.count();i++)
+    for(uint i=0;i<ActiveConfiguration->ObjectsIcons.count();i++)
     {
 	if(ActiveConfiguration->ObjectsIcons.at(i)->Tasks.Proces.find(t)>=0)
 	{
@@ -734,6 +849,7 @@ void XEPlugin_TaskManager::clonate(XSGObjectIcon *dst,XSGObjectIcon *src)
 	dst->Info.Name=src->Info.Name;
 	dst->Info.Group=src->Info.Group;
 	dst->Actions.onClickExec=src->Actions.onClickExec;
+	dst->Actions.onDropExec=src->Actions.onDropExec;
 	dst->OverText=src->OverText;
 	dst->Images.imgFileName=src->Images.imgFileName;
 
@@ -921,7 +1037,7 @@ void XEPlugin_TaskManager::xGetParameterList(QStringList *a)
  */
 void XEPlugin_TaskManager::updateXMLcfg(const QString sName)
 {
-	for(int i=0;i<ActiveConfiguration->Plugins.Plugin.count(); i++)
+	for(uint i=0;i<ActiveConfiguration->Plugins.Plugin.count(); i++)
 	{
 		if(ActiveConfiguration->Plugins.Plugin.at(i)->Info.Name=="xTaskManager")
 		{
@@ -946,22 +1062,38 @@ void XEPlugin_TaskManager::updateXMLcfg(const QString sName)
 		}
 	}
 }
-
+//#include <xeplugin_gepillow.h>
 
 /*!
     \fn XEPlugin_TaskManager::taskActivatedMultipass(Task *t)
  */
 inline void XEPlugin_TaskManager::taskActivatedMultipass(Task *t)
 {
+
 	if(xGDocker->getRaised())
 	{
+
+/*
+	// 0.35 fix for the pillow
+	XGIcon *ZeroIcon=xGDocker->getObjectIcon(0);
+	if(ZeroIcon!=NULL && ZeroIcon->xPillow!=NULL)
+	{
+	// hide
+		ZeroIcon->xPillow->hide();
+	// show it
+		ZeroIcon->xPillow->show();
+	}
+*/
+
+
+
 		if(t==NULL)
 		{
 			// is the desktop
 			xGDocker->xBliz(1);
 			return;
 		}
-		qWarning(t->visibleName());
+//		qWarning(t->visibleName());
 		if(t->getID()==QApplication::desktop()->winId())
 		{
 			// is the desktop
@@ -989,7 +1121,9 @@ inline void XEPlugin_TaskManager::taskActivatedMultipass(Task *t)
 		}
 		if(ActiveConfiguration->Icons.EnableThumbnail)
 		{
-			t->setThumbnailSize(128);
+		// 0.32
+		t->setThumbnailSize(ActiveConfiguration->Icons.SizeBig);
+		//t->setThumbnailSize(128);
 			t->updateThumbnail(2000);
 		}
 	}
@@ -1003,10 +1137,106 @@ inline void XEPlugin_TaskManager::taskActivatedCheckTitle(Task *t)
 {
 	// TODO: use Task->iconChanged signal
 	return;
-	for(int i=0;i<ActiveConfiguration->ObjectsIcons.count();i++)
+	for(uint i=0;i<ActiveConfiguration->ObjectsIcons.count();i++)
 	{
 		if(ActiveConfiguration->ObjectsIcons.at(i)->Tasks.Proces.find(t)>=0)
 		{
 		}
 	}
 }
+
+
+/*!
+    \fn XEPlugin_TaskManager::dcopPolling()
+ */
+void XEPlugin_TaskManager::dcopPolling()
+{
+	// this is the polling for checcking dcop hidden windows
+	for(uint i =0; i<ActiveConfiguration->RollingIcons.count();i++)
+	{
+		// (martind@pirack.com) Avoid null pointer when (e.g.) opening the configuration dialog for screensaver
+		if (ActiveConfiguration->RollingIcons.at(i) != NULL)
+		{
+		  usleep(ActiveConfiguration->Engine.SleepThreads);
+		  for(uint k=0;k<ActiveConfiguration->RollingIcons.at(i)->Tasks.dcopName.count();k++)
+		  {
+		  QCString pippo=QCString(ActiveConfiguration->RollingIcons.at(i)->Tasks.dcopName[k]);
+//		  qWarning(QString("%1 is running").arg(pippo));
+				if(dcopClient->isApplicationRegistered(pippo)){
+				  ActiveConfiguration->RollingIcons.at(i)->Tasks.dcopReady=1;
+				  //gotTaskInCache(ActiveConfiguration->RollingIcons.at(i));
+				  //return;
+			  }
+		  }
+		}
+	}
+
+}
+
+
+/*!
+    \fn XEPlugin_TaskManager::dcop_applicationRemoved(const QCString &)
+ */
+void XEPlugin_TaskManager::dcop_applicationRemoved(const QCString &dcopNewName)
+{
+	QString sdcopNewName=QString(dcopNewName);
+	if(sdcopNewName=="")return;
+//	qWarning(QString("dcop: removing %1").arg(sdcopNewName));
+
+	for(uint i =0; i<ActiveConfiguration->RollingIcons.count();i++)
+	{
+		// (martind@pirack.com) Avoid null pointer when (e.g.) opening the configuration dialog for screensaver
+		if (ActiveConfiguration->RollingIcons.at(i) != NULL)
+		{
+		  usleep(ActiveConfiguration->Engine.SleepThreads);
+		  for(uint k=0;k<ActiveConfiguration->RollingIcons.at(i)->Tasks.dcopName.count();k++)
+		  {
+			  if(sdcopNewName.startsWith(ActiveConfiguration->RollingIcons.at(i)->Tasks.dcopName[k],false))
+			  {
+	  		  QCString pippo=QCString(ActiveConfiguration->RollingIcons.at(i)->Tasks.dcopName[k]);
+		  	//qWarning(QString("%1 is running").arg(pippo));
+			if(dcopClient->isApplicationRegistered(pippo)){
+				  ActiveConfiguration->RollingIcons.at(i)->Tasks.dcopReady=1;
+			}
+			else
+			{
+				  ActiveConfiguration->RollingIcons.at(i)->Tasks.dcopReady=0;
+				  xGDocker->xUpdate();
+				  xGDocker->repaint(false);
+			}
+				  return;
+			  }
+		  }
+		}
+	}
+
+}
+
+
+/*!
+    \fn XEPlugin_TaskManager::dcop_applicationRegistered(const QCString &)
+ */
+void XEPlugin_TaskManager::dcop_applicationRegistered(const QCString &dcopNewName)
+{
+	QString sdcopNewName=QString(dcopNewName);	
+	if(sdcopNewName=="")return;
+//	qWarning(QString("dcop: added %1").arg(sdcopNewName));
+	for(uint i =0; i<ActiveConfiguration->RollingIcons.count();i++)
+	{
+		// (martind@pirack.com) Avoid null pointer when (e.g.) opening the configuration dialog for screensaver
+		if (ActiveConfiguration->RollingIcons.at(i) != NULL)
+		{
+		  usleep(ActiveConfiguration->Engine.SleepThreads);
+		  for(uint k=0;k<ActiveConfiguration->RollingIcons.at(i)->Tasks.dcopName.count();k++)
+		  {
+			if(ActiveConfiguration->RollingIcons.at(i)->Tasks.dcopName[k]=="")continue;
+			if(sdcopNewName.startsWith(ActiveConfiguration->RollingIcons.at(i)->Tasks.dcopName[k],false))
+			  {
+				  ActiveConfiguration->RollingIcons.at(i)->Tasks.dcopReady=1;
+				  gotTaskInCache(ActiveConfiguration->RollingIcons.at(i));
+				  return;
+			  }
+		  }
+		}
+	}
+}
