@@ -36,6 +36,11 @@
 #include <stdio.h>
 #include <stdlib.h>
 
+#include <kstandarddirs.h>
+#include <klocale.h>
+#include <kfiledialog.h>
+#include <kconfig.h>
+
 #include <kxdocker_setup_sources.h>
 
 //#undef ENABLE_FINAL
@@ -48,7 +53,8 @@ XEPlugin_XMLConf::XEPlugin_XMLConf(QObject *parent , const char *name )
 {
 //	XEObject::xPluginAdd(this);
 // this cannot be registered as a plugin since plugin are sterupped too late!
-XEObject::xSetXMLParser(this);
+	XEObject::xSetXMLParser(this);
+	ActiveConfiguration=NULL;
 }
 
 
@@ -73,7 +79,22 @@ void XEPlugin_XMLConf::xStart()
  */
 void XEPlugin_XMLConf::xStop()
 {
-    /// @todo implement me
+	if(ActiveConfiguration==NULL)return;
+	if(ActiveConfiguration->AutoSave)
+	{
+		qWarning("saving xml configuration...");
+		QString homeconfiguration=::locateLocal("data","kxdocker/")+"kxdocker_conf.xml";
+		if(homeconfiguration!=""){
+			qWarning(homeconfiguration);
+			this->xXMLStore(homeconfiguration);
+			KConfig *cfg=KGlobal::config();
+			cfg->setGroup("");
+			cfg->writeEntry("KXDockerXMLConf",homeconfiguration);
+		}
+
+
+		//ActiveConfiguration->Engine.XMLConf
+	}
 }
 
 
@@ -124,9 +145,9 @@ bool XEPlugin_XMLConf::startDocument()
 bool XEPlugin_XMLConf::startElement( const QString&a, const QString&b, const QString&c ,const QXmlAttributes& )
 {
 	xmlLevel++;
-#ifndef ENABLE_FINAL
 	char pippo[100];
 	sprintf(pippo,"(%d) %s,%s,%s",xmlLevel,(const char *)a,(const char *)b,(const char *)c);
+#ifndef ENABLE_FINAL
 	qWarning(pippo);
 #endif
 	return true;
@@ -188,14 +209,23 @@ void XEPlugin_XMLConf::xmlFetchObjectsIcons(QDomNodeList &xmlIcons,XSGObjectIcon
 	qWarning(".objectsicons: Fetching configurations");
 #endif
 	QDomNodeList xmlEngine;
-	for(int i=0; i<xmlIcons.count();i++)
+	for(uint i=0; i<xmlIcons.count();i++)
 	{
 		//ActiveConfiguration->ObjectsIcons.count();
 		XSGObjectIcon	*addedCfg=NULL;
 		if(storageIcon!=NULL)addedCfg=storageIcon;
 		else
 		{
+			// 0.35
+			/*
+	XEConfiguration *xEConfiguration=(XEConfiguration *)XEObject::xGetConfiguration();
+	addedCfg=xEConfiguration->iconAdd();
+			*/
 			addedCfg=new XSGObjectIcon;
+
+
+
+
 			// patch 0.23 for multi xml loading
 			//ActiveConfiguration->RollingIcons.append(addedCfg);
 		}
@@ -229,7 +259,7 @@ void XEPlugin_XMLConf::xmlFetchObjectsIcons(QDomNodeList &xmlIcons,XSGObjectIcon
 	
 	// check if there is another icon with same name...
 	
-	for(int i=0;i<ActiveConfiguration->RollingIcons.count();i++)
+	for(uint i=0;i<ActiveConfiguration->RollingIcons.count();i++)
 	{
 			if(ActiveConfiguration->RollingIcons.at(i)->Info.Name==
 				addedCfg->Info.Name)
@@ -263,6 +293,9 @@ void XEPlugin_XMLConf::xmlFetchObjectsIcons(QDomNodeList &xmlIcons,XSGObjectIcon
 			addedCfg->Images.imgFileArrow=
 				xmlEngine.item(0).toElement().attribute("imgFileArrow",
 				"arrow.png");
+			addedCfg->Images.imgFileDrop=
+				xmlEngine.item(0).toElement().attribute("imgFileDrop",
+				"drop.png");
 			addedCfg->PoofName=
 				xmlEngine.item(0).toElement().attribute("PoofName");
 #ifndef ENABLE_FINAL
@@ -275,6 +308,9 @@ void XEPlugin_XMLConf::xmlFetchObjectsIcons(QDomNodeList &xmlIcons,XSGObjectIcon
 		{
 			addedCfg->Actions.onClickExec=
 				xmlEngine.item(0).toElement().attribute("onClickExec");
+			addedCfg->Actions.onDropExec=
+				xmlEngine.item(0).toElement().attribute("onDropExec");
+			
 #ifndef ENABLE_FINAL
 			qWarning("objectsicons.actions.onclickexec");
 			qWarning(addedCfg->Actions.onClickExec);
@@ -300,7 +336,7 @@ void XEPlugin_XMLConf::xmlFetchObjectsIcons(QDomNodeList &xmlIcons,XSGObjectIcon
 		addedCfg->Tasks.TaskInfo=NULL;
 		addedCfg->Tasks.ShowThumbnail=0;
 		
-		for(int a=0; a<xmlSubClass.count();a++)
+		for(uint a=0; a<xmlSubClass.count();a++)
 		{
 			addedCfg->Tasks.WindowTitle.append(
 				xmlSubClass.item(a).toElement().attribute("WindowTitle"));
@@ -309,15 +345,31 @@ void XEPlugin_XMLConf::xmlFetchObjectsIcons(QDomNodeList &xmlIcons,XSGObjectIcon
 			addedCfg->Tasks.TaskName.append(
 				xmlSubClass.item(a).toElement().attribute("TaskName"));
 		}
+		//0.29
+		addedCfg->Tasks.dcopReady=0;
+		// 0.33
+		addedCfg->Tasks.forceRunning=0;
+		xmlSubClass=xmlIcons.item(i).toElement().elementsByTagName("matchdcop");
+		for(uint a=0; a<xmlSubClass.count();a++)
+		{
+			addedCfg->Tasks.dcopName.append(
+				xmlSubClass.item(a).toElement().attribute("dcopName"));
+		}
+		if(addedCfg->Tasks.dcopName.count()<1 &&addedCfg->Tasks.TaskName.count()>0)
+		{
+			addedCfg->Tasks.dcopName.append(addedCfg->Tasks.TaskName[0]);
+			//qWarning(addedCfg->Tasks.TaskName[0]);
+		}
+		
 	}
 if(storageIcon==NULL)
 {
 
 int FoundIndex;
-	for(int i=0;i<ActiveConfiguration->RollingIcons.count();i++)
+	for(uint i=0;i<ActiveConfiguration->RollingIcons.count();i++)
 	{
 		FoundIndex=-1;
-		for(int k=0; k<ActiveConfiguration->ObjectsIcons.count();k++)
+		for(uint k=0; k<ActiveConfiguration->ObjectsIcons.count();k++)
 		{
 			if(ActiveConfiguration->RollingIcons.at(i)->Info.Group==
 				ActiveConfiguration->ObjectsIcons.at(k)->Info.Group)
@@ -332,7 +384,11 @@ int FoundIndex;
 		}
 		else
 		{
-			ActiveConfiguration->ObjectsIcons.append(ActiveConfiguration->RollingIcons.at(i));
+			// 0.28 xmls for plugins
+			if(ActiveConfiguration->RollingIcons.at(i)->Info.className!="disabled")
+			{
+				ActiveConfiguration->ObjectsIcons.append(ActiveConfiguration->RollingIcons.at(i));
+			}
 		}
 	}
 }
@@ -343,7 +399,7 @@ void XEPlugin_XMLConf::xmlFetchObjectsPlugins(QDomNodeList &xmlIcons)
 	qWarning(".objectsplugins: Fetching configurations");
 #endif
 	QDomNodeList xmlEngine;
-	for(int i=0; i<xmlIcons.count();i++)
+	for(uint i=0; i<xmlIcons.count();i++)
 	{
 		XSCfgMatchIcons	*addedElement=new XSCfgMatchIcons;
 		
@@ -353,6 +409,11 @@ void XEPlugin_XMLConf::xmlFetchObjectsPlugins(QDomNodeList &xmlIcons)
 			addedElement->SystemName=xmlEngine.item(0).toElement().attribute("SystemName");
 		}
 		// New engine 07052004
+			// 0.35
+			/*
+	XEConfiguration *xEConfiguration=(XEConfiguration *)XEObject::xGetConfiguration();
+		addedElement->Icon=xEConfiguration->iconAdd();
+		*/
 		addedElement->Icon=new XSGObjectIcon;
 		xmlEngine=xmlIcons.item(i).toElement().elementsByTagName("objectsicons");
 		if(xmlEngine.count()>0)
@@ -401,7 +462,7 @@ void XEPlugin_XMLConf::xmlFetchObjectsPlugins(QDomNodeList &xmlIcons)
 		
 		// new engine with multi configurations
 	int FoundIndex=-1;
-	for(int i=0;i<ActiveConfiguration->Plugins.Matches.count();i++)
+	for(uint i=0;i<ActiveConfiguration->Plugins.Matches.count();i++)
 	{
 			if(ActiveConfiguration->Plugins.Matches.at(i)->Icon->Info.Name==
 				addedElement->Icon->Info.Name)
@@ -435,7 +496,7 @@ void XEPlugin_XMLConf::xmlFetchObjectsPlugins(QDomNodeList &xmlIcons)
 void XEPlugin_XMLConf::xmlFetchPathsIcons(QDomNodeList &xmlIcons)
 {
 	QDomNodeList xmlEngine;
-	for(int i=0; i<xmlIcons.count();i++)
+	for(uint i=0; i<xmlIcons.count();i++)
 	{
 		ActiveConfiguration->Theme.IconsPaths.append(
 			xmlIcons.item(i).toElement().attribute("Path")
@@ -450,7 +511,7 @@ void XEPlugin_XMLConf::xmlFetchPathsIcons(QDomNodeList &xmlIcons)
 void XEPlugin_XMLConf::xmlFetchPathsPlugins(QDomNodeList &xmlIcons)
 {
 	QDomNodeList xmlEngine;
-	for(int i=0; i<xmlIcons.count();i++)
+	for(uint i=0; i<xmlIcons.count();i++)
 	{
 		ActiveConfiguration->Plugins.PluginsPaths.append(
 			xmlIcons.item(i).toElement().attribute("Path")
@@ -465,7 +526,7 @@ void XEPlugin_XMLConf::xmlFetchPathsPlugins(QDomNodeList &xmlIcons)
 void XEPlugin_XMLConf::xmlFetchPlugins(QDomNodeList &xmlIcons)
 {
 	QDomNodeList xmlEngine;
-	for(int i=0; i<xmlIcons.count();i++)
+	for(uint i=0; i<xmlIcons.count();i++)
 	{
 #ifndef ENABLE_FINAL
 		qWarning("void XEPlugin_XMLConf::xmlFetchPlugins(QDomNodeList &xmlIcons)");
@@ -533,7 +594,7 @@ void XEPlugin_XMLConf::xXMLStore(const QString &fileName)
 	xCfgStore(doc,kxdocker);
 	QDomElement 	xmlIconsObjects=doc.createElement("objects");
 	kxdocker.appendChild(xmlIconsObjects);
-	for(int i=0;i<ActiveConfiguration->RollingIcons.count();i++)
+	for(uint i=0;i<ActiveConfiguration->RollingIcons.count();i++)
 	{
 		xmlStoreObjectsIcons(doc,xmlIconsObjects,	
 			ActiveConfiguration->RollingIcons.at(i)
@@ -541,7 +602,7 @@ void XEPlugin_XMLConf::xXMLStore(const QString &fileName)
 	}
 	
 	
-	for(int i=0;i<ActiveConfiguration->Plugins.Matches.count();i++)
+	for(uint i=0;i<ActiveConfiguration->Plugins.Matches.count();i++)
 	{
 		QDomElement 	xmlMatch=doc.createElement("objectsplugins");
 		kxdocker.appendChild(xmlMatch);
@@ -616,15 +677,17 @@ void XEPlugin_XMLConf::xmlStoreObjectsIcons(QDomDocument &doc, QDomElement &root
 	
 	xmlObjectImages.setAttribute("imgFileArrow",
 	icon->Images.imgFileArrow);
+	xmlObjectImages.setAttribute("imgFileDrop",
+	icon->Images.imgFileDrop);
 	xmlObjectImages.setAttribute("imgFileName",
 	icon->Images.imgFileName);
 	xmlObjectImages.setAttribute("PoofName",
 	icon->PoofName);
 	
-	xmlObjectActions.setAttribute("onClickExec",
-	icon->Actions.onClickExec);
+	xmlObjectActions.setAttribute("onClickExec",icon->Actions.onClickExec);
+	xmlObjectActions.setAttribute("onDropExec",icon->Actions.onDropExec);
 	
-	for(int i=0;i<icon->Tasks.WindowTitle.count();i++)
+	for(uint i=0;i<icon->Tasks.WindowTitle.count();i++)
 	{
 		QDomElement xmlObjectMatch=doc.createElement("matchtasks");
 		xmlObjectIcon.appendChild(xmlObjectMatch);
@@ -638,9 +701,32 @@ void XEPlugin_XMLConf::xmlStoreObjectsIcons(QDomDocument &doc, QDomElement &root
 		xmlObjectMatch.setAttribute("ClassName",
 		icon->Tasks.ClassName[i]);
 	}
+/*
+		xmlSubClass=xmlIcons.item(i).toElement().elementsByTagName("matchdcop");
+		for(uint a=0; a<xmlSubClass.count();a++)
+		{
+			addedCfg->Tasks.dcopName.append(
+				xmlSubClass.item(a).toElement().attribute("dcopName"));
+		}
+		if(addedCfg->Tasks.dcopName.count()<1 &&addedCfg->Tasks.TaskName.count()>0)
+		{
+			addedCfg->Tasks.dcopName.append(addedCfg->Tasks.TaskName[0]);
+			//qWarning(addedCfg->Tasks.TaskName[0]);
+		}
+*/
+	
+	for(uint i=0;i<icon->Tasks.dcopName.count();i++)
+	{
+		QDomElement xmlObjectMatch=doc.createElement("matchdcop");
+		xmlObjectIcon.appendChild(xmlObjectMatch);
+		
+		xmlObjectMatch.setAttribute("dcopName",
+		icon->Tasks.dcopName[i]);
+	}
+
 	QDomElement xmlObjectPluginConfigurations=doc.createElement("pluginconfiguration");
 	xmlObjectIcon.appendChild(xmlObjectPluginConfigurations);
-	for(int i=0;i<icon->PluginConfiguration.count();i++)
+	for(uint i=0;i<icon->PluginConfiguration.count();i++)
 	{
 	
 		QDomNode childcopy=icon->PluginConfiguration.item(i).cloneNode();
@@ -649,7 +735,7 @@ void XEPlugin_XMLConf::xmlStoreObjectsIcons(QDomDocument &doc, QDomElement &root
 	
 	QDomElement xmlObjectActionList=doc.createElement("actionlist");
 	xmlObjectIcon.appendChild(xmlObjectActionList);
-	for(int i=0;i<icon->Actions.ActionList.count();i++)
+	for(uint i=0;i<icon->Actions.ActionList.count();i++)
 	{
 	
 		QDomNode childcopy=icon->Actions.ActionList.item(i).cloneNode();
@@ -682,6 +768,12 @@ void XEPlugin_XMLConf::xCfgStore(QDomDocument &doc, QDomElement &kxdocker)
 	ActiveConfiguration->Engine.XMLConf);
 	xmlEngine.setAttribute("AndZoomCache",
 	ActiveConfiguration->Engine.AndZoomCache);
+	xmlEngine.setAttribute("AutoSave",
+	ActiveConfiguration->AutoSave);
+
+	xmlEngine.setAttribute("AutoResize",
+	ActiveConfiguration->AutoResize);
+
 #ifdef ENABLE_SPECIALENGINE2
 	xmlEngine.setAttribute("InterpolationValue",
 	ActiveConfiguration->Engine.InterpolationValue);
@@ -719,7 +811,7 @@ void XEPlugin_XMLConf::xCfgStore(QDomDocument &doc, QDomElement &kxdocker)
 	xmlIcons.setAttribute("Separation",
 	ActiveConfiguration->Icons.Separation);
 	xmlIcons.setAttribute("Size",
-	ActiveConfiguration->Icons.Size);
+	ActiveConfiguration->Icons.SizePrefer);
 	xmlIcons.setAttribute("SizeBig",
 	ActiveConfiguration->Icons.SizeBig);
 	xmlIcons.setAttribute("Design",
@@ -736,6 +828,8 @@ void XEPlugin_XMLConf::xCfgStore(QDomDocument &doc, QDomElement &kxdocker)
 	ActiveConfiguration->Window.HideMouseEdge);
 	xmlWindow.setAttribute("AutoHideTimeout",
 	ActiveConfiguration->Window.HideTimeout);
+	xmlWindow.setAttribute("FastHide",
+	ActiveConfiguration->Window.FastHide);
 	xmlWindow.setAttribute("SendToForgroundTimeout",
 	ActiveConfiguration->Window.SendToForgroundTimeout);
 	
@@ -775,7 +869,7 @@ void XEPlugin_XMLConf::xCfgStore(QDomDocument &doc, QDomElement &kxdocker)
 	xmlTheme.setAttribute("PoofPath",
 	ActiveConfiguration->Theme.PoofPath);
 	
-	for(int i=0; i<ActiveConfiguration->Theme.IconsPaths.count();i++)
+	for(uint i=0; i<ActiveConfiguration->Theme.IconsPaths.count();i++)
 	{
 		QDomElement 	xmlIconsPath=doc.createElement("iconspaths");
 		xmlGeneral.appendChild(xmlIconsPath);
@@ -788,6 +882,9 @@ void XEPlugin_XMLConf::xCfgStore(QDomDocument &doc, QDomElement &kxdocker)
 	xmlBackground.setAttribute("Tiled",
 		ActiveConfiguration->Theme.Background.Tiled
 		);
+	xmlBackground.setAttribute("Desaturate",
+		ActiveConfiguration->Theme.Background.Desaturate
+		);
 	xmlBackground.setAttribute("imgBackgroundCenter",
 		ActiveConfiguration->Theme.Background.imgBackgroundCenter
 		);
@@ -803,7 +900,7 @@ void XEPlugin_XMLConf::xCfgStore(QDomDocument &doc, QDomElement &kxdocker)
 	xmlBackground.setAttribute("imgBackgroundSeparator",
 		ActiveConfiguration->Theme.Background.imgBackgroundSeparator
 		);
-	for(int i=0; i<ActiveConfiguration->Plugins.Plugin.count();i++)
+	for(uint i=0; i<ActiveConfiguration->Plugins.Plugin.count();i++)
 	{
 		QDomElement 	xmlPlugin=doc.createElement("plugin");
 		xmlPlugins.appendChild(xmlPlugin);
@@ -837,7 +934,7 @@ ActiveConfiguration->Plugins.Plugin.at(i)->xmlConfiguration.count();
 void XEPlugin_XMLConf::xXMLExplode()
 {
 	// explode general plugin configurations
-	for(int i=0;i<ActiveConfiguration->Plugins.Plugin.count();i++)
+	for(uint i=0;i<ActiveConfiguration->Plugins.Plugin.count();i++)
 	{
 		QObject *pf=XEObject::xFindObject(ActiveConfiguration->Plugins.Plugin.at(i)->Info.Name);
 		if(!pf)continue;
@@ -853,7 +950,7 @@ void XEPlugin_XMLConf::xXMLExplode()
 		ActiveConfiguration->RollingIcons.at(i)->PluginConfiguration=makeNodeList(pf);	
 	}
 	// matches
-	for(int i=0;i<ActiveConfiguration->Plugins.Matches.count();i++)
+	for(uint i=0;i<ActiveConfiguration->Plugins.Matches.count();i++)
 	{
 		QObject *pf=XEObject::xFindObject(ActiveConfiguration->Plugins.Matches.at(i)->Icon->Info.className);
 		if(!pf)continue;
@@ -896,7 +993,7 @@ QDomNodeList XEPlugin_XMLConf::makeNodeList(QObject *newplugin)
 		newplugin,
 		SLOT(xGetParameter(const QString,QString&)));
 	
-	for(int istoringXML=0;istoringXML<a.count();istoringXML++)
+	for(uint istoringXML=0;istoringXML<a.count();istoringXML++)
 	{
 		QString returnValue;
 		clientGetParameter(a[istoringXML],returnValue);
@@ -918,7 +1015,7 @@ QDomNodeList XEPlugin_XMLConf::makeNodeList(QObject *newplugin)
  */
 void XEPlugin_XMLConf::xImportXMLs()
 {
-	for(int i=0;i<ActiveConfiguration->ConfigurationsPaths.count();i++)
+	for(uint i=0;i<ActiveConfiguration->ConfigurationsPaths.count();i++)
 	{
 		//qWarning(ActiveConfiguration->ConfigurationsPaths[i]);
 		QString xmlsPath=::locate("data",ActiveConfiguration->ConfigurationsPaths[i]);
@@ -1032,6 +1129,8 @@ void XEPlugin_XMLConf::xLoadXML(const QString XMLConf)
 			xmlFetch("SleepAnimations",ActiveConfiguration->Engine.SleepAnimations,xmlEngine);
 			xmlFetch("MaxIconsShowed",ActiveConfiguration->Engine.MaxIconsShowed,xmlEngine);
 			xmlFetch("SleepFPS",ActiveConfiguration->Engine.SleepFPS,xmlEngine);
+			xmlFetch("AutoResize",ActiveConfiguration->AutoResize,xmlEngine);
+
 			xmlFetch("SleepThreads",ActiveConfiguration->Engine.SleepThreads,xmlEngine);
 			xmlFetch("AndZoomCache",ActiveConfiguration->Engine.AndZoomCache,xmlEngine);
 #ifdef ENABLE_SPECIALENGINE2
@@ -1047,8 +1146,12 @@ void XEPlugin_XMLConf::xLoadXML(const QString XMLConf)
 			qWarning(".general.icons");
 #endif
 			xmlFetch("Horiz",ActiveConfiguration->Icons.Horiz,xmlEngine);
-			xmlFetch("Size",ActiveConfiguration->Icons.Size,xmlEngine);
+			xmlFetch("Size",ActiveConfiguration->Icons.SizePrefer,xmlEngine);
+			//0.30
+			ActiveConfiguration->Icons.Size=ActiveConfiguration->Icons.SizePrefer;
+			
 			xmlFetch("SizeBig",ActiveConfiguration->Icons.SizeBig,xmlEngine);
+
 			xmlFetch("Raise",ActiveConfiguration->Icons.Raise,xmlEngine);
 			xmlFetch("Separation",ActiveConfiguration->Icons.Separation,xmlEngine);
 			xmlFetch("EnableThumbnail",ActiveConfiguration->Icons.EnableThumbnail,xmlEngine);
@@ -1083,6 +1186,7 @@ void XEPlugin_XMLConf::xLoadXML(const QString XMLConf)
 			xmlFetch("LeftForce",ActiveConfiguration->Window.LeftForce,xmlEngine);
 			xmlFetch("TopForce",ActiveConfiguration->Window.TopForce,xmlEngine);
 			xmlFetch("AutoHideTimeout",ActiveConfiguration->Window.HideTimeout,xmlEngine);
+			xmlFetch("FastHide",ActiveConfiguration->Window.FastHide,xmlEngine);
 			xmlFetch("SendToBackground",ActiveConfiguration->Window.SendToBackground,xmlEngine);
 			xmlFetch("HideMouseCornerLeft",ActiveConfiguration->Window.HideMouseCornerLeft,xmlEngine);
 			xmlFetch("HideMouseCornerRight",ActiveConfiguration->Window.HideMouseCornerRight,xmlEngine);
@@ -1116,6 +1220,7 @@ void XEPlugin_XMLConf::xLoadXML(const QString XMLConf)
 			if(xmlSubClass.count()>0)
 			{
 				xmlFetch("Tiled",ActiveConfiguration->Theme.Background.Tiled,xmlSubClass);
+				xmlFetch("Desaturate",ActiveConfiguration->Theme.Background.Desaturate,xmlSubClass);
 				ActiveConfiguration->Theme.Background.imgBackgroundCenter=
 					xmlSubClass.item(0).toElement().attribute(
 					"imgBackgroundCenter",
